@@ -2,7 +2,7 @@
 
 source $(dirname $0)/test.inc.sh
 
-pocount
+python $PYTHON_ARGS $(which pocount)
 start_checks
 startswithi_stderr "Usage"
 end_checks
