@@ -2,5 +2,5 @@
 
 source $(dirname $0)/test.inc.sh
 
-pocount --csv $one
+python $PYTHON_ARGS $(which pocount) --csv $one
 check_results
