@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009-2010 Zuza Software Foundation
 #
@@ -25,17 +23,17 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+from io import StringIO
+
 from translate.convert import convert
 from translate.storage import factory
 
 
 class po2pydict:
-
     def __init__(self):
         return
 
     def convertstore(self, inputstore, includefuzzy):
-        from cStringIO import StringIO
         str_obj = StringIO()
 
         mydict = dict()
@@ -45,41 +43,41 @@ class po2pydict:
             if unit.istranslated() or (includefuzzy and unit.isfuzzy()):
                 mydict[unit.source] = unit.target
             else:
-                mydict[unit.source] = unit.source
-                # The older convention is to prefix with "*** ":
-                #mydict[unit.source] = '*** ' + unit.source
+                mydict[unit.source] = unit.source.replace("@markmin\x01", "")
 
-        str_obj.write('{\n')
-        for source_str in mydict:
-            str_obj.write("%s:%s,\n" % (repr(str(source_str)), repr(str(mydict[source_str]))))
-        str_obj.write('}\n')
+        str_obj.write("# -*- coding: utf-8 -*-\n")
+        str_obj.write("{\n")
+        for source_str, trans_str in sorted(mydict.items()):
+            str_obj.write("{}: {},\n".format(repr(source_str), repr(trans_str)))
+        str_obj.write("}\n")
         str_obj.seek(0)
         return str_obj
 
 
-def convertpy(inputfile, outputfile, templatefile=None, includefuzzy=False,
-              outputthreshold=None):
+def convertpy(
+    inputfile, outputfile, templatefile=None, includefuzzy=False, outputthreshold=None
+):
     inputstore = factory.getobject(inputfile)
 
     if not convert.should_output_store(inputstore, outputthreshold):
-        return False
+        return 0
 
     convertor = po2pydict()
     outputstring = convertor.convertstore(inputstore, includefuzzy)
-    outputfile.write(outputstring.read())
+
+    outputfile.write(bytes(outputstring.read(), "utf-8"))
     return 1
 
 
 def main(argv=None):
-    from translate.misc import stdiotell
-    import sys
-    sys.stdout = stdiotell.StdIOWrapper(sys.stdout)
-    formats = {("po", "py"): ("py", convertpy), ("po"): ("py", convertpy)}
-    parser = convert.ConvertOptionParser(formats, usetemplates=False, description=__doc__)
+    formats = {("po", "py"): ("py", convertpy), ("po", None): ("py", convertpy)}
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=False, description=__doc__
+    )
     parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
