@@ -1,23 +1,22 @@
-# -*- coding: utf-8 -*-
+from io import BytesIO
 
 from translate.convert import mozfunny2prop
-from translate.misc import wStringIO
 from translate.storage import po
 
 
-class TestInc2PO(object):
-
+class TestInc2PO:
     def inc2po(self, incsource, inctemplate=None):
         """helper that converts .inc source to po source without requiring files"""
-        inputfile = wStringIO.StringIO(incsource)
+        inputfile = BytesIO(incsource.encode())
         if inctemplate:
-            templatefile = wStringIO.StringIO(inctemplate)
+            templatefile = BytesIO(inctemplate.encode())
         else:
             templatefile = None
-        outputfile = wStringIO.StringIO()
+        outputfile = BytesIO()
         result = mozfunny2prop.inc2po(inputfile, outputfile, templatefile)
+        assert result == 1
         outputpo = outputfile.getvalue()
-        outputpofile = po.pofile(wStringIO.StringIO(outputpo))
+        outputpofile = po.pofile(BytesIO(outputpo))
         return outputpofile
 
     def singleelement(self, pofile):
@@ -35,7 +34,7 @@ class TestInc2PO(object):
 
     def test_simpleentry(self):
         """checks that a simple inc entry converts properly to a po entry"""
-        incsource = '#define MOZ_LANGPACK_CREATOR mozilla.org\n'
+        incsource = "#define MOZ_LANGPACK_CREATOR mozilla.org\n"
         pofile = self.inc2po(incsource)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["MOZ_LANGPACK_CREATOR"]
@@ -44,9 +43,9 @@ class TestInc2PO(object):
 
     def test_uncomment_contributors(self):
         """checks that the contributors entry is automatically uncommented"""
-        incsource = '''# If non-English locales wish to credit multiple contributors, uncomment this
+        incsource = """# If non-English locales wish to credit multiple contributors, uncomment this
 # variable definition and use the format specified.
-# #define MOZ_LANGPACK_CONTRIBUTORS <em:contributor>Joe Solon</em:contributor> <em:contributor>Suzy Solon</em:contributor>'''
+# #define MOZ_LANGPACK_CONTRIBUTORS <em:contributor>Joe Solon</em:contributor> <em:contributor>Suzy Solon</em:contributor>"""
         pofile = self.inc2po(incsource)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["MOZ_LANGPACK_CONTRIBUTORS"]
