@@ -198,7 +198,7 @@ class TestPO2TMXCommand(test_convert.TestConvertCommand, TestPO2TMX):
 
     def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
+        options = super().test_help(capsys)
         options = self.help_check(options, "-l LANG, --language=LANG")
         options = self.help_check(options, "--source-language=LANG")
         options = self.help_check(options, "--comments", last=True)
