@@ -1,34 +1,39 @@
-# -*- coding: utf-8 -*-
-
 # tiki2po unit tests
 # Author: Wil Clouser <wclouser@mozilla.com>
 # Date: 2008-12-01
 
+from io import BytesIO
+
 from translate.convert import test_convert, tiki2po
-from translate.misc import wStringIO
 
 
-class TestTiki2Po(object):
+class TestTiki2Po:
 
     ConverterClass = tiki2po.tiki2po
 
-    def _convert(self, input_string, template_string=None,
-                 include_unused=False, success_expected=True):
+    def _convert(
+        self,
+        input_string,
+        template_string=None,
+        include_unused=False,
+        success_expected=True,
+    ):
         """Helper that converts to target format without using files."""
-        input_file = wStringIO.StringIO(input_string)
-        output_file = wStringIO.StringIO()
+        input_file = BytesIO(input_string.encode())
+        output_file = BytesIO()
         template_file = None
         if template_string:
-            template_file = wStringIO.StringIO(template_string)
+            template_file = BytesIO(template_string.encode())
         expected_result = 1 if success_expected else 0
-        converter = self.ConverterClass(input_file, output_file, template_file,
-                                        include_unused)
+        converter = self.ConverterClass(
+            input_file, output_file, template_file, include_unused
+        )
         assert converter.run() == expected_result
         return converter.target_store, output_file
 
     def _convert_to_string(self, *args, **kwargs):
         """Helper that converts to target format string without using files."""
-        return self._convert(*args, **kwargs)[1].getvalue().decode('utf-8')
+        return self._convert(*args, **kwargs)[1].getvalue().decode("utf-8")
 
     def test_convert_empty(self):
         """Check converting empty file returns no output."""
@@ -42,7 +47,7 @@ class TestTiki2Po(object):
 // ### end of unused words
 """
         output = self._convert_to_string(input_string)
-        assert '#: translated' in output
+        assert "#: translated" in output
         assert 'msgid "zero_source"' in output
         assert "one_source" not in output
 
@@ -54,18 +59,19 @@ class TestTiki2Po(object):
 // ### end of unused words
 """
         output = self._convert_to_string(input_string, include_unused=True)
-        assert '#: translated' in output
+        assert "#: translated" in output
         assert 'msgid "zero_source"' in output
-        assert '#: unused' in output
+        assert "#: unused" in output
         assert 'msgid "one_source"' in output
 
 
 class TestTiki2PoCommand(test_convert.TestConvertCommand, TestTiki2Po):
     """Tests running actual tiki2po commands on files"""
+
     convertmodule = tiki2po
     defaultoptions = {}
 
     def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
+        options = super().test_help(capsys)
         options = self.help_check(options, "--include-unused")
