@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2008,2010-2011 Zuza Software Foundation
 #
@@ -25,7 +24,6 @@ for examples and usage instructions.
 
 import logging
 import os
-import six
 import time
 
 from translate.filters import autocorrect, checks, pofilter
@@ -35,9 +33,16 @@ from translate.storage import factory, oo
 logger = logging.getLogger(__name__)
 
 
-class reoo(object):
-
-    def __init__(self, templatefile, languages=None, timestamp=None, includefuzzy=False, long_keys=False, filteraction="exclude"):
+class reoo:
+    def __init__(
+        self,
+        templatefile,
+        languages=None,
+        timestamp=None,
+        includefuzzy=False,
+        long_keys=False,
+        filteraction="exclude",
+    ):
         """construct a reoo converter for the specified languages (timestamp=0 means leave unchanged)"""
         # languages is a pair of language ids
         self.long_keys = long_keys
@@ -57,7 +62,7 @@ class reoo(object):
     def makeindex(self):
         """makes an index of the oo keys that are used in the source file"""
         self.index = {}
-        for ookey, theoo in six.iteritems(self.o.ookeys):
+        for ookey, theoo in self.o.ookeys.items():
             sourcekey = oo.makekey(ookey, self.long_keys)
             self.index[sourcekey] = theoo
 
@@ -74,24 +79,25 @@ class reoo(object):
         # technically our formats should just have one location for each entry...
         # but we handle multiple ones just to be safe...
         for location in locations:
-            subkeypos = location.rfind('.')
-            subkey = location[subkeypos+1:]
+            subkeypos = location.rfind(".")
+            subkey = location[subkeypos + 1 :]
             key = location[:subkeypos]
             # this is just to handle our old system of using %s/%s:%s instead of %s/%s#%s
-            key = key.replace(':', '#')
+            key = key.replace(":", "#")
             # this is to handle using / instead of \ in the sourcefile...
-            key = key.replace('\\', '/')
+            key = key.replace("\\", "/")
             key = oo.normalizefilename(key)
             if key in self.index:
                 # now we need to replace the definition of entity with msgstr
                 theoo = self.index[key]  # find the oo
                 self.applytranslation(key, subkey, theoo, unit)
             else:
-                logger.warning("couldn't find key %s from po in %d keys",
-                               key, len(self.index))
+                logger.warning(
+                    "couldn't find key %s from po in %d keys", key, len(self.index)
+                )
                 try:
                     sourceunitlines = str(unit)
-                    if isinstance(sourceunitlines, six.text_type):
+                    if isinstance(sourceunitlines, str):
                         sourceunitlines = sourceunitlines.encode("utf-8")
                     logger.warning(sourceunitlines)
                 except Exception:
@@ -116,12 +122,11 @@ class reoo(object):
                 makecopy = True
         if makecopy:
             part2 = oo.ooline(part1.getparts())
-        unquotedid = unit.source
         unquotedstr = unit.target
         # If there is no translation, we don't want to add a line
         if len(unquotedstr.strip()) == 0:
             return
-        if isinstance(unquotedstr, six.text_type):
+        if isinstance(unquotedstr, str):
             unquotedstr = unquotedstr.encode("UTF-8")
         # finally set the new definition in the oo, but not if its empty
         if len(unquotedstr) > 0:
@@ -148,11 +153,11 @@ class reoo(object):
 
 def getmtime(filename):
     import stat
+
     return time.localtime(os.stat(filename)[stat.ST_MTIME])
 
 
 class oocheckfilter(pofilter.pocheckfilter):
-
     def validelement(self, unit, filename, filteraction):
         """Returns whether or not to use unit in conversion. (filename is just for error reporting)"""
         if filteraction == "none":
@@ -160,28 +165,30 @@ class oocheckfilter(pofilter.pocheckfilter):
         filterresult = self.filterunit(unit)
         if filterresult:
             if filterresult != autocorrect:
-                for filtername, filtermessage in six.iteritems(filterresult):
+                for filtername, filtermessage in filterresult.items():
                     location = unit.getlocations()[0]
                     if filtername in self.options.error:
-                        logger.error("Error at %s::%s: %s",
-                                     filename, location, filtermessage)
+                        logger.error(
+                            "Error at %s::%s: %s", filename, location, filtermessage
+                        )
                         return filteraction not in ["exclude-all", "exclude-serious"]
                     if filtername in self.options.warning or self.options.alwayswarn:
-                        logger.warning("Warning at %s::%s: %s",
-                                       filename, location, filtermessage)
+                        logger.warning(
+                            "Warning at %s::%s: %s", filename, location, filtermessage
+                        )
                         return filteraction not in ["exclude-all"]
         return True
 
 
-class oofilteroptions(object):
-    error = ['variables', 'xmltags', 'escapes']
-    warning = ['blank']
-    #To only issue warnings for tests listed in warning, change the following to False:
+class oofilteroptions:
+    error = ["variables", "xmltags", "escapes"]
+    warning = ["blank"]
+    # To only issue warnings for tests listed in warning, change the following to False:
     alwayswarn = True
     limitfilters = error + warning
-    #To use all available tests, uncomment the following:
-    #limitfilters = []
-    #To exclude certain tests, list them in here:
+    # To use all available tests, uncomment the following:
+    # limitfilters = []
+    # To exclude certain tests, list them in here:
     excludefilters = {}
     includefuzzy = False
     includereview = False
@@ -189,14 +196,27 @@ class oofilteroptions(object):
 
 
 options = oofilteroptions()
-filter = oocheckfilter(options, [checks.OpenOfficeChecker, checks.StandardUnitChecker], checks.openofficeconfig)
+filter = oocheckfilter(
+    options,
+    [checks.OpenOfficeChecker, checks.StandardUnitChecker],
+    checks.openofficeconfig,
+)
 
 
-def convertoo(inputfile, outputfile, templatefile, sourcelanguage=None,
-              targetlanguage=None, timestamp=None, includefuzzy=False,
-              multifilestyle="single", skip_source=False, filteraction=None):
+def convertoo(
+    inputfile,
+    outputfile,
+    templatefile,
+    sourcelanguage=None,
+    targetlanguage=None,
+    timestamp=None,
+    includefuzzy=False,
+    multifilestyle="single",
+    skip_source=False,
+    filteraction=None,
+):
     inputstore = factory.getobject(inputfile)
-    inputstore.filename = getattr(inputfile, 'name', '')
+    inputstore.filename = getattr(inputfile, "name", "")
     if not targetlanguage:
         raise ValueError("You must specify the target language")
     if not sourcelanguage:
@@ -208,10 +228,14 @@ def convertoo(inputfile, outputfile, templatefile, sourcelanguage=None,
     if templatefile is None:
         raise ValueError("must have template file for oo files")
     else:
-        convertor = reoo(templatefile, languages=languages,
-                         timestamp=timestamp, includefuzzy=includefuzzy,
-                         long_keys=multifilestyle != "single",
-                         filteraction=filteraction)
+        convertor = reoo(
+            templatefile,
+            languages=languages,
+            timestamp=timestamp,
+            includefuzzy=includefuzzy,
+            long_keys=multifilestyle != "single",
+            filteraction=filteraction,
+        )
     outputstore = convertor.convertstore(inputstore)
     # TODO: check if we need to manually delete missing items
     outputfile.write(outputstore.__str__(skip_source, targetlanguage))
@@ -220,6 +244,7 @@ def convertoo(inputfile, outputfile, templatefile, sourcelanguage=None,
 
 def main(argv=None):
     from translate.convert import convert
+
     formats = {
         ("po", "oo"): ("oo", convertoo),
         ("xlf", "oo"): ("oo", convertoo),
@@ -228,31 +253,70 @@ def main(argv=None):
         ("xliff", "sdf"): ("sdf", convertoo),
     }
     # always treat the input as an archive unless it is a directory
-    archiveformats = {(None, "output"): oo.oomultifile, (None, "template"): oo.oomultifile}
-    parser = convert.ArchiveConvertOptionParser(formats, usetemplates=True, description=__doc__, archiveformats=archiveformats)
-    parser.add_option("-l", "--language", dest="targetlanguage", default=None,
-                      help="set target language code (e.g. af-ZA) [required]",
-                      metavar="LANG")
-    parser.add_option("", "--source-language", dest="sourcelanguage",
-                      default=None,
-                      help="set source language code (default en-US)",
-                      metavar="LANG")
+    archiveformats = {
+        (None, "output"): oo.oomultifile,
+        (None, "template"): oo.oomultifile,
+    }
+    parser = convert.ArchiveConvertOptionParser(
+        formats, usetemplates=True, description=__doc__, archiveformats=archiveformats
+    )
     parser.add_option(
-        "-T", "--keeptimestamp", dest="timestamp", default=None,
-        action="store_const", const=0,
-        help="don't change the timestamps of the strings")
-    parser.add_option("", "--nonrecursiveoutput", dest="allowrecursiveoutput",
-                      default=True, action="store_false",
-                      help="don't treat the output oo as a recursive store")
-    parser.add_option("", "--nonrecursivetemplate",
-                      dest="allowrecursivetemplate", default=True,
-                      action="store_false",
-                      help="don't treat the template oo as a recursive store")
-    parser.add_option("", "--skipsource", dest="skip_source", default=False,
-                      action="store_true",
-                      help="don't output the source language, but fallback to it where needed")
-    parser.add_option("", "--filteraction", dest="filteraction", default="none", metavar="ACTION",
-                      help="action on pofilter failure: none (default), warn, exclude-serious, exclude-all")
+        "-l",
+        "--language",
+        dest="targetlanguage",
+        default=None,
+        help="set target language code (e.g. af-ZA) [required]",
+        metavar="LANG",
+    )
+    parser.add_option(
+        "",
+        "--source-language",
+        dest="sourcelanguage",
+        default=None,
+        help="set source language code (default en-US)",
+        metavar="LANG",
+    )
+    parser.add_option(
+        "-T",
+        "--keeptimestamp",
+        dest="timestamp",
+        default=None,
+        action="store_const",
+        const=0,
+        help="don't change the timestamps of the strings",
+    )
+    parser.add_option(
+        "",
+        "--nonrecursiveoutput",
+        dest="allowrecursiveoutput",
+        default=True,
+        action="store_false",
+        help="don't treat the output oo as a recursive store",
+    )
+    parser.add_option(
+        "",
+        "--nonrecursivetemplate",
+        dest="allowrecursivetemplate",
+        default=True,
+        action="store_false",
+        help="don't treat the template oo as a recursive store",
+    )
+    parser.add_option(
+        "",
+        "--skipsource",
+        dest="skip_source",
+        default=False,
+        action="store_true",
+        help="don't output the source language, but fallback to it where needed",
+    )
+    parser.add_option(
+        "",
+        "--filteraction",
+        dest="filteraction",
+        default="none",
+        metavar="ACTION",
+        help="action on pofilter failure: none (default), warn, exclude-serious, exclude-all",
+    )
     parser.add_fuzzy_option()
     parser.add_multifile_option()
     parser.passthrough.append("sourcelanguage")
@@ -263,5 +327,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
