@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007,2009,2011 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: http://en.wikipedia.org/wiki/Arabic_language
 """
 
-from __future__ import unicode_literals
 
 import re
 
@@ -32,7 +30,8 @@ from translate.lang import common
 def reverse_quotes(text):
     def convertquotation(match):
         return "”%s“" % match.group(1)
-    return re.sub('“([^”]+)”', convertquotation, text)
+
+    return re.sub("“([^”]+)”", convertquotation, text)
 
 
 class ar(common.Common):
@@ -44,8 +43,8 @@ class ar(common.Common):
         ",": "،",
         ";": "؛",
         "?": "؟",
-        #This causes problems with variables, so commented out for now:
-        #"%": "٪",
+        # This causes problems with variables, so commented out for now:
+        # "%": "٪",
     }
 
     numbertuple = (
@@ -62,10 +61,10 @@ class ar(common.Common):
     )
 
     ignoretests = {
-        'all': ["acronyms", "simplecaps", "startcaps"],
+        "all": ["acronyms", "simplecaps", "startcaps"],
     }
 
     @classmethod
     def punctranslate(cls, text):
-        text = super(cls, cls).punctranslate(text)
+        text = super().punctranslate(text)
         return reverse_quotes(text)
