@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2008 Zuza Software Foundation
 #
@@ -60,6 +58,7 @@ TODOs and Ideas for possible features:
   - phrases
 """
 
+
 import logging
 import re
 
@@ -69,7 +68,7 @@ from translate.lang import data
 logger = logging.getLogger(__name__)
 
 
-class Common(object):
+class Common:
     """This class is the common parent class for all language classes."""
 
     code = ""
@@ -119,74 +118,100 @@ class Common(object):
     """This of languages that has different plural formula in Mozilla than the
     standard one in Gettext."""
 
-    listseperator = u", "
+    listseperator = ", "
     """This string is used to separate lists of textual elements. Most
     languages probably can stick with the default comma, but Arabic and some
     Asian languages might want to override this."""
 
-    specialchars = u""
+    specialchars = ""
     """Characters used by the language that might not be easy to input with
     common keyboard layouts"""
 
-    commonpunc = u".,;:!?-@#$%^*_()[]{}/\\'`\"<>"
+    commonpunc = ".,;:!?-@#$%^*_()[]{}/\\'`\"<>"
     """These punctuation marks are common in English and most languages that
     use latin script."""
 
-    quotes = u"‘’‛“”„‟′″‴‵‶‷‹›«»"
+    quotes = "‘’‛“”„‟′″‴‵‶‷‹›«»"
     """These are different quotation marks used by various languages."""
 
-    invertedpunc = u"¿¡"
+    invertedpunc = "¿¡"
     """Inverted punctuation sometimes used at the beginning of sentences in
     Spanish, Asturian, Galician, and Catalan."""
 
-    rtlpunc = u"،؟؛÷"
+    rtlpunc = "،؟؛÷"
     """These punctuation marks are used by Arabic and Persian, for example."""
 
-    CJKpunc = u"。、，；！？「」『』【】"
+    CJKpunc = "。、，；！？「」『』【】"
     """These punctuation marks are used in certain circumstances with CJK
     languages."""
 
-    indicpunc = u"।॥॰"
+    indicpunc = "।॥॰"
     """These punctuation marks are used by several Indic languages."""
 
-    ethiopicpunc = u"።፤፣"
+    ethiopicpunc = "።፤፣"
     """These punctuation marks are used by several Ethiopic languages."""
 
-    miscpunc = u"…±°¹²³·©®×£¥€"
+    miscpunc = "…±°¹²³·©®×£¥€"
     """The middle dot (·) is used by Greek and Georgian."""
 
-    punctuation = u"".join([commonpunc, quotes, invertedpunc, rtlpunc, CJKpunc,
-                            indicpunc, ethiopicpunc, miscpunc])
+    punctuation = "".join(
+        [
+            commonpunc,
+            quotes,
+            invertedpunc,
+            rtlpunc,
+            CJKpunc,
+            indicpunc,
+            ethiopicpunc,
+            miscpunc,
+        ]
+    )
     """We include many types of punctuation here, simply since this is only
     meant to determine if something is punctuation. Hopefully we catch some
     languages which might not be represented with modules. Most languages won't
     need to override this."""
 
-    sentenceend = u".!?…։؟।。！？።\u06d4"
+    sentenceend = ".!?…։؟।。！？።\u06d4"
     """These marks can indicate a sentence end. Once again we try to account
     for many languages. Most langauges won't need to override this."""
 
-    #The following tries to account for a lot of things. For the best idea of
-    #what works, see test_common.py. We try to ignore abbreviations, for
-    #example, by checking that the following sentence doesn't start with lower
-    #case or numbers.
-    sentencere = re.compile(ur"""
+    # The following tries to account for a lot of things. For the best idea of
+    # what works, see test_common.py. We try to ignore abbreviations, for
+    # example, by checking that the following sentence doesn't start with lower
+    # case or numbers.
+    sentencere = re.compile(
+        r"""
         (?s)        # make . also match newlines
         .*?         # anything, but match non-greedy
         [%s]        # the puntuation for sentence ending
         \s+         # the spacing after the puntuation
         (?=[^a-zа-џ\d])  # lookahead that next part starts with caps
-        """ % sentenceend, re.VERBOSE | re.UNICODE)
+        """
+        % sentenceend,
+        re.VERBOSE | re.UNICODE,
+    )
 
     puncdict = {}
     """A dictionary of punctuation transformation rules that can be used by
     punctranslate()."""
 
-    ignoretests = []
-    """List of pofilter tests for this language that must be ignored."""
+    numbertuple = ()
+    """A tuple of number transformation rules that can be used by
+    numbertranslate()."""
+
+    ignoretests = {}
+    """Dictionary of tests to ignore in some or all checkers.
+
+    Keys are checker names and values are list of names for the ignored tests
+    in the checker. A special 'all' checker name can be used to tell that the
+    tests must be ignored in all the checkers.
+
+    Listed checkers to ignore tests on must be lowercase strings for the
+    checker name, for example "mozilla" for MozillaChecker or "libreoffice" for
+    LibreOfficeChecker."""
 
     checker = None
-    """A language specific checker (see filters.checks).
+    """A language specific checker instance (see filters.checks).
 
     This doesn't need to be supplied, but will be used if it exists."""
 
@@ -205,7 +230,8 @@ class Common(object):
 
     def __new__(cls, code):
         """This returns the language class for the given code, following a
-        singleton like approach (only one object per language)."""
+        singleton like approach (only one object per language).
+        """
         code = code or ""
         # First see if a language object for this code already exists
         if code in cls._languages:
@@ -217,8 +243,7 @@ class Common(object):
         while code:
             langdata = data.get_language(code)
             if langdata:
-                language.fullname, language.nplurals, \
-                    language.pluralequation = langdata
+                language.fullname, language.nplurals, language.pluralequation = langdata
                 break
             code = data.simplercode(code)
         return language
@@ -229,43 +254,55 @@ class Common(object):
 
     def __repr__(self):
         """Give a simple string representation without address information to
-        be able to store it in text for comparison later."""
+        be able to store it in text for comparison later.
+        """
         detail = ""
         if self.code:
             detail = "(%s)" % self.code
         return "<class 'translate.lang.common.Common%s'>" % detail
 
+    @classmethod
+    def numbertranslate(cls, text):
+        """Converts the numbers in a string according to the rules of the
+        language.
+        """
+        if text:
+            for latin_number, native_number in cls.numbertuple:
+                text = text.replace(native_number, latin_number)
+        return text
+
     @classmethod
     def punctranslate(cls, text):
         """Converts the punctuation in a string according to the rules of the
-        language."""
-        #TODO: look at po::escapeforpo() for performance idea
+        language.
+        """
+        # TODO: look at po::escapeforpo() for performance idea
         if not text:
             return text
-        ellipses_end = text.endswith(u"...")
+        ellipses_end = text.endswith("...")
         if ellipses_end:
             text = text[:-3]
-        for source, target in cls.puncdict.iteritems():
+        for source, target in cls.puncdict.items():
             text = text.replace(source, target)
         if ellipses_end:
-            if u"..." in cls.puncdict:
-                text += cls.puncdict[u"..."]
+            if "..." in cls.puncdict:
+                text += cls.puncdict["..."]
             else:
-                text += u"..."
+                text += "..."
         # Let's account for cases where a punctuation symbol plus a space is
         # replaced, but the space won't exist at the end of the source message.
         # As a simple improvement for messages ending in ellipses (...), we
         # test that the last character is different from the second last
         # This is only relevant if the string has two characters or more
-        if ((text[-1] + u" " in cls.puncdict) and
-            (len(text) < 2 or text[-2] != text[-1])):
-            text = text[:-1] + cls.puncdict[text[-1] + u" "].rstrip()
+        if (text[-1] + " " in cls.puncdict) and (len(text) < 2 or text[-2] != text[-1]):
+            text = text[:-1] + cls.puncdict[text[-1] + " "].rstrip()
         return text
 
     @classmethod
     def length_difference(cls, length):
         """Returns an estimate to a likely change in length relative to an
-        English string of length length."""
+        English string of length length.
+        """
         # This is just a rudimentary heuristic guessing that most translations
         # will be somewhat longer than the source language
         expansion_factor = 0
@@ -285,28 +322,30 @@ class Common(object):
     def alter_length(cls, text):
         """Converts the given string by adding or removing characters as an
         estimation of translation length (with English assumed as source
-        language)."""
+        language).
+        """
 
         def alter_it(text):
             l = len(text)
             if l > 9:
                 extra = cls.length_difference(l)
                 if extra > 0:
-                    text = text[:extra].replace(u'\n', u'') + text
+                    text = text[:extra].replace("\n", "") + text
                 else:
                     text = text[-extra:]
             return text
+
         expanded = []
-        for subtext in text.split(u"\n\n"):
+        for subtext in text.split("\n\n"):
             expanded.append(alter_it(subtext))
-        text = u"\n\n".join(expanded)
+        text = "\n\n".join(expanded)
         return text
 
     @classmethod
     def character_iter(cls, text):
         """Returns an iterator over the characters in text."""
-        #We don't return more than one consecutive whitespace character
-        prev = 'A'
+        # We don't return more than one consecutive whitespace character
+        prev = "A"
         for c in text:
             if c.isspace() and prev.isspace():
                 continue
@@ -322,7 +361,7 @@ class Common(object):
     @classmethod
     def word_iter(cls, text):
         """Returns an iterator over the words in text."""
-        #TODO: Consider replacing puctuation with space before split()
+        # TODO: Consider replacing puctuation with space before split()
         for w in text.split():
             word = w.strip(cls.punctuation)
             if word:
