@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2016 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: https://en.wikipedia.org/wiki/Danish_language
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
@@ -30,8 +28,10 @@ from translate.lang import common
 class da(common.Common):
     """This class represents Danish."""
 
-    validaccel = ("abcdefghijklmnopqrstuvwxyz"
-                  "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                  "1234567890"
-                  "æøåé"
-                  "ÆØÅÉ")
+    validaccel = (
+        "abcdefghijklmnopqrstuvwxyz"
+        "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+        "1234567890"
+        "æøåé"
+        "ÆØÅÉ"
+    )
