@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007, 2010 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: http://en.wikipedia.org/wiki/Persian_language
 """
 
-from __future__ import unicode_literals
 
 import re
 
@@ -30,14 +28,13 @@ from translate.lang import common
 
 
 def guillemets(text):
-
     def convertquotation(match):
         prefix = match.group(1)
         # Let's see that we didn't perhaps match an XML tag property like
         # <a href="something">
         if prefix == "=":
             return match.group(0)
-        return "%s«%s»" % (prefix, match.group(2))
+        return "{}«{}»".format(prefix, match.group(2))
 
     # Check that there is an even number of double quotes, otherwise it is
     # probably not safe to convert them.
@@ -45,11 +42,11 @@ def guillemets(text):
         text = re.sub('(.|^)"([^"]+)"', convertquotation, text)
     singlecount = text.count("'")
     if singlecount:
-        if singlecount == text.count('`'):
+        if singlecount == text.count("`"):
             text = re.sub("(.|^)`([^']+)'", convertquotation, text)
         elif singlecount % 2 == 0:
             text = re.sub("(.|^)'([^']+)'", convertquotation, text)
-    text = re.sub('(.|^)“([^”]+)”', convertquotation, text)
+    text = re.sub("(.|^)“([^”]+)”", convertquotation, text)
     return text
 
 
@@ -62,14 +59,13 @@ class fa(common.Common):
         ",": "،",
         ";": "؛",
         "?": "؟",
-        #This causes problems with variables, so commented out for now:
-        #"%": "٪",
+        # This causes problems with variables, so commented out for now:
+        # "%": "٪",
     }
 
     numbertuple = (
         # It seems that Persian uses both Arabic-Indic and Extended
         # Arabic-Indic digits.
-
         ("0", "٠"),  # U+0660 Arabic-Indic digit zero.
         ("1", "١"),  # U+0661 Arabic-Indic digit one.
         ("2", "٢"),  # U+0662 Arabic-Indic digit two.
@@ -80,7 +76,6 @@ class fa(common.Common):
         ("7", "٧"),  # U+0667 Arabic-Indic digit seven.
         ("8", "٨"),  # U+0668 Arabic-Indic digit eight.
         ("9", "٩"),  # U+0669 Arabic-Indic digit nine.
-
         ("0", "۰"),  # U+06F0 Extended Arabic-Indic digit zero.
         ("1", "۱"),  # U+06F1 Extended Arabic-Indic digit one.
         ("2", "۲"),  # U+06F2 Extended Arabic-Indic digit two.
@@ -94,13 +89,13 @@ class fa(common.Common):
     )
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
-    #TODO: check persian numerics
-    #TODO: zwj and zwnj?
+    # TODO: check persian numerics
+    # TODO: zwj and zwnj?
 
     @classmethod
     def punctranslate(cls, text):
         """Implement "French" quotation marks."""
-        text = super(cls, cls).punctranslate(text)
+        text = super().punctranslate(text)
         return guillemets(text)
