@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -23,10 +21,11 @@
 .. seealso:: http://en.wikipedia.org/wiki/Gaelic_language
 """
 
+
 from translate.lang import common
 
 
 class gd(common.Common):
     """This class represents Gaelic."""
 
-    specialchars = u'àòùèìÀÈÌÒÙ'
+    specialchars = "àòùèìÀÈÌÒÙ⁊┐’…“”»‌‑"
