@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2008, 2011 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: http://en.wikipedia.org/wiki/Armenian_language
 """
 
-from __future__ import unicode_literals
 
 import re
 
@@ -34,18 +32,28 @@ class hy(common.Common):
 
     armenianpunc = "։՝՜՞"
 
-    punctuation = "".join([common.Common.commonpunc, common.Common.quotes,
-                           common.Common.miscpunc, armenianpunc])
+    punctuation = "".join(
+        [
+            common.Common.commonpunc,
+            common.Common.quotes,
+            common.Common.miscpunc,
+            armenianpunc,
+        ]
+    )
 
     sentenceend = "։՝՜…"
 
-    sentencere = re.compile(r"""
+    sentencere = re.compile(
+        r"""
         (?s)        # make . also match newlines
         .*?         # anything, but match non-greedy
         [%s]        # the puntuation for sentence ending
         \s+         # the spacing after the puntuation
         (?=[^a-zա-ֆ\d])  # lookahead that next part starts with caps
-        """ % sentenceend, re.VERBOSE | re.UNICODE)
+        """
+        % sentenceend,
+        re.VERBOSE | re.UNICODE,
+    )
 
     puncdict = {
         ".": "։",
@@ -55,7 +63,7 @@ class hy(common.Common):
     }
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
 
     mozilla_nplurals = 2
