@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010, 2016 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: http://en.wikipedia.org/wiki/Marathi_language
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
@@ -31,5 +29,5 @@ class mr(common.Common):
     """This class represents Marathi."""
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
