@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -25,6 +24,7 @@
    (v1.4.2) to ensure that we match currently released versions of Poedit.
 """
 
+
 lang_codes = {
     "aa": "Afar",
     "ab": "Abkhazian",
@@ -195,7 +195,7 @@ lang_codes = {
 """ISO369 codes and names as used by Poedit.
 Mostly these are identical to ISO 639, but there are some differences."""
 
-lang_names = dict([(value, key) for (key, value) in lang_codes.items()])
+lang_names = {value: key for (key, value) in lang_codes.items()}
 """Reversed :data:`lang_codes`"""
 
 dialects = {
