@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2019 Cademia Siciliana <tech@cademiasiciliana.org>
 #
@@ -22,9 +21,8 @@
 .. seealso:: http://en.wikipedia.org/wiki/Sicilian_language
 """
 
-from __future__ import unicode_literals
 
-from translate.filters.checks import FilterFailure, TranslationChecker, CheckerConfig
+from translate.filters.checks import CheckerConfig, FilterFailure, TranslationChecker
 from translate.filters.decorators import critical
 from translate.lang import common
 
@@ -58,7 +56,7 @@ class SicilianChecker(TranslationChecker):
             kwargs["checkerconfig"] = checkerconfig
 
         checkerconfig.update(sicilianconfig)
-        TranslationChecker.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
     @critical
     def italianisms(self, str1, str2):
@@ -84,15 +82,19 @@ class SicilianChecker(TranslationChecker):
         # The above is full of strange quotes and things in utf-8 encoding.
         # single apostrophe perhaps problematic in words like "doesn't"
         for separator in self.config.punctuation:
-            str1 = str1.replace(separator, u" ")
-            str2 = str2.replace(separator, u" ")
+            str1 = str1.replace(separator, " ")
+            str2 = str2.replace(separator, " ")
 
         words1 = self.filteraccelerators(str1).split()
         words2 = self.filteraccelerators(str2).split()
-        stopwords = ["%s (%s)" % (word, errors[word]) for word in words2 if word.lower() in errors.keys() and word not in words1]
+        stopwords = [
+            "{} ({})".format(word, errors[word])
+            for word in words2
+            if word.lower() in errors.keys() and word not in words1
+        ]
 
         if stopwords:
-            raise FilterFailure(u"Please translate: %s" % (u", ".join(stopwords)))
+            raise FilterFailure("Please translate: %s" % (", ".join(stopwords)))
 
         return True
 
@@ -111,17 +113,17 @@ class SicilianChecker(TranslationChecker):
         :param str2: the target (translated) string
         :return: True if there are no words with endings not in respect of vocalism (or if they appear in source string as well)
         """
-        exceptions = ['me', 'to', 'so', 'po', 'no', 'jo', 'se', 'nne']
+        exceptions = ["me", "to", "so", "po", "no", "jo", "se", "nne"]
 
         stopwords = []
 
         for word in self.config.lang.words(str2):
             if word not in str1 and word.lower() not in exceptions:
-                if word.lower().endswith(('e', 'o')) and word.lower() not in stopwords:
+                if word.lower().endswith(("e", "o")) and word.lower() not in stopwords:
                     stopwords.append(word.lower())
 
         if stopwords:
-            raise FilterFailure(u"Please respect vocalism: %s" % (u", ".join(stopwords)))
+            raise FilterFailure("Please respect vocalism: %s" % (", ".join(stopwords)))
         return True
 
     @critical
@@ -141,10 +143,12 @@ class SicilianChecker(TranslationChecker):
         for word in self.config.lang.words(str2):
             for suffix in suffixes.keys():
                 if word not in str1 and word.lower().endswith(suffix):
-                    stopwords.append("%s (-%s)" % (word, suffixes[suffix]))
+                    stopwords.append("{} (-{})".format(word, suffixes[suffix]))
 
         if stopwords:
-            raise FilterFailure(u"Please use the correct word endings: %s" % (u", ".join(stopwords)))
+            raise FilterFailure(
+                "Please use the correct word endings: %s" % (", ".join(stopwords))
+            )
         return True
 
 
@@ -154,5 +158,5 @@ class scn(common.Common):
     checker = SicilianChecker()
 
     ignoretests = {
-        'all': ['doublewords'],
+        "all": ["doublewords"],
     }
