@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
 #
@@ -23,10 +21,13 @@
 .. seealso:: http://en.wikipedia.org/wiki/Sinhala_language
 """
 
+
 from translate.lang import common
 
 
 class si(common.Common):
     """This class represents Sinhala."""
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        "all": ["simplecaps", "startcaps"],
+    }
