@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -21,10 +19,11 @@
 """This module represents the Southern Sotho language.
 """
 
+
 from translate.lang import common
 
 
 class st(common.Common):
     """This class represents Southern Sotho."""
 
-    validdoublewords = [u"o", u"le", u"ba"]
+    validdoublewords = ["o", "le", "ba"]
