@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: http://en.wikipedia.org/wiki/Swedish_language
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
@@ -30,8 +28,10 @@ from translate.lang import common
 class sv(common.Common):
     """This class represents Swedish."""
 
-    validaccel = ("abcdefghijklmnopqrstuvwxyz"
-                  "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                  "1234567890"
-                  "åäö"
-                  "ÅÄÖ")
+    validaccel = (
+        "abcdefghijklmnopqrstuvwxyz"
+        "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+        "1234567890"
+        "åäö"
+        "ÅÄÖ"
+    )
