@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright 2002, 2003 St James Software
 #
 # This file is part of translate.
@@ -21,29 +19,28 @@
 dictionary
 """
 
-import six
-
 
 class cidict(dict):
-
     def __init__(self, fromdict=None):
         """constructs the cidict, optionally using another dict to do so"""
         if fromdict is not None:
             self.update(fromdict)
 
     def __getitem__(self, key):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
                 return dict.__getitem__(self, akey)
         raise IndexError
 
     def __setitem__(self, key, value):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
                 return dict.__setitem__(self, akey, value)
@@ -53,22 +50,24 @@ class cidict(dict):
         """D.update(E) -> None.
         Update D from E: for k in E.keys(): D[k] = E[k]
         """
-        for key, value in six.iteritems(updatedict):
+        for key, value in updatedict.items():
             self[key] = value
 
     def __delitem__(self, key):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
                 return dict.__delitem__(self, akey)
         raise IndexError
 
     def __contains__(self, key):
-        if not isinstance(key, six.string_types):
-            raise TypeError("cidict can only have str or unicode as key (got %r)" %
-                            type(key))
+        if not isinstance(key, str):
+            raise TypeError(
+                "cidict can only have str or unicode as key (got %r)" % type(key)
+            )
         for akey in self.keys():
             if akey.lower() == key.lower():
                 return 1
