@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2007 Zuza Software Foundation
 #
@@ -26,7 +25,6 @@ as minidom.parseString, since the functionality provided here will not be in
 those objects.
 """
 
-import six
 from xml.dom import expatbuilder, minidom
 
 
@@ -48,9 +46,9 @@ def writexml_helper(self, writer, indent="", addindent="", newl=""):
     a_names = sorted(attrs.keys())
 
     for a_name in a_names:
-        writer.write(" %s=\"" % a_name)
+        writer.write(' %s="' % a_name)
         minidom._write_data(writer, attrs[a_name].value)
-        writer.write("\"")
+        writer.write('"')
     if self.childNodes:
         # We need to write text nodes without newline and indentation, so
         # we handle them differently. Note that we here assume that "empty"
@@ -67,14 +65,14 @@ def writexml_helper(self, writer, indent="", addindent="", newl=""):
             writer.write(">")
             for node in self.childNodes:
                 node.writexml(writer, "", "", "")
-            writer.write("</%s>%s" % (self.tagName, newl))
+            writer.write(f"</{self.tagName}>{newl}")
         else:
             # This is the normal case that we do with pretty layout
             writer.write(">%s" % (newl))
             for node in self.childNodes:
                 if node.nodeType != self.TEXT_NODE:
                     node.writexml(writer, (indent + addindent), addindent, newl)
-            writer.write("%s</%s>%s" % (indent, self.tagName, newl))
+            writer.write(f"{indent}</{self.tagName}>{newl}")
     else:
         writer.write("/>%s" % (newl))
 
@@ -87,22 +85,22 @@ def getElementsByTagName_helper(parent, name, dummy=None):
     yieldElementsByTagName
     """
     for node in parent.childNodes:
-        if (node.nodeType == minidom.Node.ELEMENT_NODE and
-            (name == "*" or node.tagName == name)):
+        if node.nodeType == minidom.Node.ELEMENT_NODE and (
+            name == "*" or node.tagName == name
+        ):
             yield node
         if node.hasChildNodes():
-            for othernode in node.getElementsByTagName(name):
-                yield othernode
+            yield from node.getElementsByTagName(name)
 
 
 def searchElementsByTagName_helper(parent, name, onlysearch):
     """limits the search to within tags occuring in onlysearch"""
     for node in parent.childNodes:
-        if (node.nodeType == minidom.Node.ELEMENT_NODE and
-            (name == "*" or node.tagName == name)):
+        if node.nodeType == minidom.Node.ELEMENT_NODE and (
+            name == "*" or node.tagName == name
+        ):
             yield node
-        if (node.nodeType == minidom.Node.ELEMENT_NODE and
-            node.tagName in onlysearch):
+        if node.nodeType == minidom.Node.ELEMENT_NODE and node.tagName in onlysearch:
             for node in node.searchElementsByTagName(name, onlysearch):
                 yield node
 
@@ -118,17 +116,16 @@ def getnodetext(node):
         return ""
     return "".join([t.data for t in node.childNodes if t.nodeType == t.TEXT_NODE])
 
+
 # various modifications to minidom classes to add functionality we like
 
 
 class DOMImplementation(minidom.DOMImplementation):
-
     def _create_document(self):
         return Document()
 
 
 class Element(minidom.Element):
-
     def yieldElementsByTagName(self, name):
         return getElementsByTagName_helper(self, name)
 
@@ -166,11 +163,11 @@ theDOMImplementation = DOMImplementation()
 
 
 class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
-
     def reset(self):
         """Free all data structures used during DOM construction."""
         self.document = theDOMImplementation.createDocument(
-            expatbuilder.EMPTY_NAMESPACE, None, None)
+            expatbuilder.EMPTY_NAMESPACE, None, None
+        )
         self.curNode = self.document
         self._elem_info = self.document._elem_info
         self._cdata = False
@@ -180,7 +177,7 @@ class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
         # All we want to do is construct our own Element instead of
         # minidom.Element, unfortunately the only way to do this is to
         # copy this whole function from expatbuilder.py
-        if ' ' in name:
+        if " " in name:
             uri, localname, prefix, qname = expatbuilder._parse_ns_name(self, name)
         else:
             uri = expatbuilder.EMPTY_NAMESPACE
@@ -196,52 +193,50 @@ class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
             for prefix, uri in self._ns_ordered_prefixes:
                 if prefix:
                     a = minidom.Attr(
-                        expatbuilder._intern(self, 'xmlns:' + prefix),
-                        expatbuilder.XMLNS_NAMESPACE, prefix, "xmlns")
+                        expatbuilder._intern(self, "xmlns:" + prefix),
+                        expatbuilder.XMLNS_NAMESPACE,
+                        prefix,
+                        "xmlns",
+                    )
                 else:
-                    a = minidom.Attr("xmlns", expatbuilder.XMLNS_NAMESPACE,
-                                     "xmlns", expatbuilder.EMPTY_PREFIX)
-                if six.PY2:
-                    d = a.childNodes[0].__dict__
-                    d['data'] = d['nodeValue'] = uri
-                    d = a.__dict__
-                    d['value'] = d['nodeValue'] = uri
-                    d['ownerDocument'] = self.document
-                else:
-                    a.value = uri
-                    a.ownerDocument = self.document
+                    a = minidom.Attr(
+                        "xmlns",
+                        expatbuilder.XMLNS_NAMESPACE,
+                        "xmlns",
+                        expatbuilder.EMPTY_PREFIX,
+                    )
+                a.value = uri
+                a.ownerDocument = self.document
                 expatbuilder._set_attribute_node(node, a)
             del self._ns_ordered_prefixes[:]
 
         if attributes:
-            if hasattr(node, '_ensure_attributes'):
+            if hasattr(node, "_ensure_attributes"):
                 node._ensure_attributes()  # Python 3 only
             _attrs = node._attrs
             _attrsNS = node._attrsNS
             for i in range(0, len(attributes), 2):
                 aname = attributes[i]
-                value = attributes[i+1]
-                if ' ' in aname:
-                    uri, localname, prefix, qname = expatbuilder._parse_ns_name(self, aname)
+                value = attributes[i + 1]
+                if " " in aname:
+                    uri, localname, prefix, qname = expatbuilder._parse_ns_name(
+                        self, aname
+                    )
                     a = minidom.Attr(qname, uri, localname, prefix)
                     _attrs[qname] = a
                     _attrsNS[(uri, localname)] = a
                 else:
-                    a = minidom.Attr(aname, expatbuilder.EMPTY_NAMESPACE,
-                                     aname, expatbuilder.EMPTY_PREFIX)
+                    a = minidom.Attr(
+                        aname,
+                        expatbuilder.EMPTY_NAMESPACE,
+                        aname,
+                        expatbuilder.EMPTY_PREFIX,
+                    )
                     _attrs[aname] = a
                     _attrsNS[(expatbuilder.EMPTY_NAMESPACE, aname)] = a
-                if six.PY2:
-                    d = a.childNodes[0].__dict__
-                    d['data'] = d['nodeValue'] = value
-                    d = a.__dict__
-                    d['ownerDocument'] = self.document
-                    d['value'] = d['nodeValue'] = value
-                    d['ownerElement'] = node
-                else:
-                    a.ownerDocument = self.document
-                    a.value = value
-                    a.ownerElement = node
+                a.ownerDocument = self.document
+                a.value = value
+                a.ownerElement = node
 
     if __debug__:
         # This only adds some asserts to the original
@@ -251,27 +246,32 @@ class ExpatBuilderNS(expatbuilder.ExpatBuilderNS):
 
         def end_element_handler(self, name):
             curNode = self.curNode
-            if ' ' in name:
+            if " " in name:
                 uri, localname, prefix, qname = expatbuilder._parse_ns_name(self, name)
-                assert (curNode.namespaceURI == uri
-                        and curNode.localName == localname
-                        and curNode.prefix == prefix), "element stack messed up! (namespace)"
+                assert (
+                    curNode.namespaceURI == uri
+                    and curNode.localName == localname
+                    and curNode.prefix == prefix
+                ), "element stack messed up! (namespace)"
             else:
-                assert curNode.nodeName == name, \
-                    "element stack messed up - bad nodeName"
-                assert curNode.namespaceURI == expatbuilder.EMPTY_NAMESPACE, \
-                    "element stack messed up - bad namespaceURI"
+                assert (
+                    curNode.nodeName == name
+                ), "element stack messed up - bad nodeName"
+                assert (
+                    curNode.namespaceURI == expatbuilder.EMPTY_NAMESPACE
+                ), "element stack messed up - bad namespaceURI"
             self.curNode = curNode.parentNode
             self._finish_end_element(curNode)
 
+
 # parser methods that use our modified xml classes
 
 
 def parse(file, parser=None, bufsize=None):
     """Parse a file into a DOM by filename or file object."""
     builder = ExpatBuilderNS()
-    if isinstance(file, six.string_types):
-        with open(file, 'rb') as fp:
+    if isinstance(file, str):
+        with open(file, "rb") as fp:
             result = builder.parseFile(fp)
     else:
         result = builder.parseFile(file)
