@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
 #
@@ -22,12 +21,10 @@ import shutil
 import tempfile
 from zipfile import ZipFile
 
-import six
-
-from translate.storage.projstore import *
+from translate.storage.projstore import FileNotInProjectError, ProjectStore
 
 
-__all__ = ('BundleProjectStore', 'InvalidBundleError')
+__all__ = ("BundleProjectStore", "InvalidBundleError")
 
 
 class InvalidBundleError(Exception):
@@ -39,21 +36,21 @@ class BundleProjectStore(ProjectStore):
 
     # INITIALIZERS #
     def __init__(self, fname):
-        super(BundleProjectStore, self).__init__()
+        super().__init__()
         self._tempfiles = {}
         if fname and os.path.isfile(fname):
             self.load(fname)
         else:
-            self.zip = ZipFile(fname, 'w')
+            self.zip = ZipFile(fname, "w")
             self.save()
             self.zip.close()
-            self.zip = ZipFile(fname, 'a')
+            self.zip = ZipFile(fname, "a")
 
     # CLASS METHODS #
     @classmethod
     def from_project(cls, proj, fname=None):
         if fname is None:
-            fname = 'bundle.zip'
+            fname = "bundle.zip"
 
         bundle = BundleProjectStore(fname)
         for fn in proj.sourcefiles:
@@ -67,7 +64,7 @@ class BundleProjectStore(ProjectStore):
         return bundle
 
     # METHODS #
-    def append_file(self, afile, fname, ftype='trans', delete_orig=False):
+    def append_file(self, afile, fname, ftype="trans", delete_orig=False):
         """Append the given file to the project with the given filename, marked
         to be of type ``ftype`` ('src', 'trans', 'tgt').
 
@@ -81,13 +78,13 @@ class BundleProjectStore(ProjectStore):
         """
         if fname and fname in self.zip.namelist():
             raise ValueError("File already in bundle archive: %s" % (fname))
-        if not fname and isinstance(afile, six.string_types) and afile in self.zip.namelist():
+        if not fname and isinstance(afile, str) and afile in self.zip.namelist():
             raise ValueError("File already in bundle archive: %s" % (afile))
 
-        afile, fname = super(BundleProjectStore, self).append_file(afile, fname, ftype)
+        afile, fname = super().append_file(afile, fname, ftype)
         self._zip_add(fname, afile)
 
-        if delete_orig and hasattr(afile, 'name') and afile.name not in self._tempfiles:
+        if delete_orig and hasattr(afile, "name") and afile.name not in self._tempfiles:
             try:
                 os.unlink(afile.name)
             except Exception:
@@ -97,9 +94,9 @@ class BundleProjectStore(ProjectStore):
 
     def remove_file(self, fname, ftype=None):
         """Remove the file with the given project name from the project."""
-        super(BundleProjectStore, self).remove_file(fname, ftype)
+        super().remove_file(fname, ftype)
         self._zip_delete([fname])
-        tempfiles = [tmpf for tmpf, prjf in six.iteritems(self._tempfiles) if prjf == fname]
+        tempfiles = [tmpf for tmpf, prjf in self._tempfiles.items() if prjf == fname]
         if tempfiles:
             for tmpf in tempfiles:
                 try:
@@ -109,7 +106,7 @@ class BundleProjectStore(ProjectStore):
                 del self._tempfiles[tmpf]
 
     def close(self):
-        super(BundleProjectStore, self).close()
+        super().close()
         self.cleanup()
         self.zip.close()
 
@@ -127,18 +124,20 @@ class BundleProjectStore(ProjectStore):
         retfile = None
         if fname in self._files or fname in self.zip.namelist():
             # Check if the file has not already been extracted to a temp file
-            tempfname = [tfn for tfn in self._tempfiles if self._tempfiles[tfn] == fname]
+            tempfname = [
+                tfn for tfn in self._tempfiles if self._tempfiles[tfn] == fname
+            ]
             if tempfname and os.path.isfile(tempfname[0]):
                 tempfname = tempfname[0]
             else:
-                tempfname = ''
+                tempfname = ""
             if not tempfname:
                 # Extract the file to a temporary file
                 zfile = self.zip.open(fname)
                 tempfname = os.path.split(fname)[-1]
-                tempfd, tempfname = tempfile.mkstemp(suffix='_' + tempfname)
+                tempfd, tempfname = tempfile.mkstemp(suffix="_" + tempfname)
                 os.close(tempfd)
-                open(tempfname, 'w').write(zfile.read())
+                open(tempfname, "w").write(zfile.read())
             retfile = open(tempfname)
             self._tempfiles[tempfname] = fname
 
@@ -149,26 +148,26 @@ class BundleProjectStore(ProjectStore):
     def get_proj_filename(self, realfname):
         """Try and find a project file name for the given real file name."""
         try:
-            fname = super(BundleProjectStore, self).get_proj_filename(realfname)
-        except ValueError as ve:
+            fname = super().get_proj_filename(realfname)
+        except ValueError:
             fname = None
         if fname:
             return fname
         if realfname in self._tempfiles:
             return self._tempfiles[realfname]
-        raise ValueError('Real file not in project store: %s' % (realfname))
+        raise ValueError("Real file not in project store: %s" % (realfname))
 
     def load(self, zipname):
         """Load the bundle project from the zip file of the given name."""
-        self.zip = ZipFile(zipname, mode='a')
+        self.zip = ZipFile(zipname, mode="a")
         self._load_settings()
 
         append_section = {
-            'sources': self._sourcefiles.append,
-            'targets': self._targetfiles.append,
-            'transfiles': self._transfiles.append,
+            "sources": self._sourcefiles.append,
+            "targets": self._targetfiles.append,
+            "transfiles": self._transfiles.append,
         }
-        for section in ('sources', 'targets', 'transfiles'):
+        for section in ("sources", "targets", "transfiles"):
             if section in self.settings:
                 for fname in self.settings[section]:
                     append_section[section](fname)
@@ -179,19 +178,19 @@ class BundleProjectStore(ProjectStore):
         self._update_from_tempfiles()
 
         if filename:
-            newzip = ZipFile(filename, 'w')
+            newzip = ZipFile(filename, "w")
         else:
             newzip = self._create_temp_zipfile()
 
         # Write project file for the new zip bundle
-        newzip.writestr('project.xtp', self._generate_settings())
+        newzip.writestr("project.xtp", self._generate_settings())
         # Copy project files from project to the new zip file
         project_files = self._sourcefiles + self._transfiles + self._targetfiles
         for fname in project_files:
             newzip.writestr(fname, self.get_file(fname).read())
         # Copy any extra (non-project) files from the current zip
         for fname in self.zip.namelist():
-            if fname in project_files or fname == 'project.xtp':
+            if fname in project_files or fname == "project.xtp":
                 continue
             newzip.writestr(fname, self.zip.read(fname))
 
@@ -207,22 +206,25 @@ class BundleProjectStore(ProjectStore):
             raise FileNotInProjectError(pfname)
 
         if pfname not in self.zip.namelist():
-            return super(BundleProjectStore, self).update_file(pfname, infile)
+            super().update_file(pfname, infile)
+            return
 
         self._zip_delete([pfname])
         self._zip_add(pfname, infile)
 
     def _load_settings(self):
         """Grab the project.xtp file from the zip file and load it."""
-        if 'project.xtp' not in self.zip.namelist():
-            raise InvalidBundleError('Not a translate project bundle')
-        super(BundleProjectStore, self)._load_settings(self.zip.open('project.xtp').read())
+        if "project.xtp" not in self.zip.namelist():
+            raise InvalidBundleError("Not a translate project bundle")
+        super()._load_settings(self.zip.open("project.xtp").read())
 
     def _create_temp_zipfile(self):
         """Create a new zip file with a temporary file name (with mode 'w')."""
-        newzipfd, newzipfname = tempfile.mkstemp(prefix='translate_bundle', suffix='.zip')
+        newzipfd, newzipfname = tempfile.mkstemp(
+            prefix="translate_bundle", suffix=".zip"
+        )
         os.close(newzipfd)
-        return ZipFile(newzipfname, 'w')
+        return ZipFile(newzipfname, "w")
 
     def _replace_project_zip(self, zfile):
         """Replace the currently used zip file (``self.zip``) with the given
@@ -234,7 +236,7 @@ class BundleProjectStore(ProjectStore):
         if not self.zip.fp.closed:
             self.zip.close()
         shutil.move(zfile.filename, self.zip.filename)
-        self.zip = ZipFile(self.zip.filename, mode='a')
+        self.zip = ZipFile(self.zip.filename, mode="a")
 
     def _update_from_tempfiles(self):
         """Update project files from temporary files."""
@@ -246,7 +248,7 @@ class BundleProjectStore(ProjectStore):
 
     def _zip_add(self, pfname, infile):
         """Add the contents of ``infile`` to the zip with file name ``pfname``."""
-        if hasattr(infile, 'seek'):
+        if hasattr(infile, "seek"):
             infile.seek(0)
         self.zip.writestr(pfname, infile.read())
         # Clear the cached file object to force the file to be read from the
@@ -266,13 +268,13 @@ class BundleProjectStore(ProjectStore):
                 raise KeyError("File not in zip archive: %s" % (fn))
 
         newzip = self._create_temp_zipfile()
-        newzip.writestr('project.xtp', self._generate_settings())
+        newzip.writestr("project.xtp", self._generate_settings())
 
         for fname in zippedfiles:
             # Copy all files from self.zip that are not project.xtp (already
             # in the new zip file) or in fnames (they are to be removed, after
             # all.
-            if fname in fnames or fname == 'project.xtp':
+            if fname in fnames or fname == "project.xtp":
                 continue
             newzip.writestr(fname, self.zip.read(fname))
 
