@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006-2010 Zuza Software Foundation
 #
@@ -20,38 +19,42 @@
 """factory methods to build real storage objects that conform to base.py"""
 
 import os
-import six
+from functools import lru_cache
+from importlib import import_module
+
+from translate.storage.base import TranslationStore
+from translate.storage.directory import Directory
 
 
-#TODO: Monolingual formats (with template?)
+# TODO: Monolingual formats (with template?)
 
 decompressclass = {
-    'gz': ("gzip", "GzipFile"),
-    'bz2': ("bz2", "BZ2File"),
+    "gz": ("gzip", "GzipFile"),
+    "bz2": ("bz2", "BZ2File"),
 }
 
 
 _classes_str = {
     "csv": ("csvl10n", "csvfile"),
-    "tab": ("omegat", "OmegaTFileTab"), "utf8": ("omegat", "OmegaTFile"),
-    "po": ("po", "pofile"), "pot": ("po", "pofile"),
-    "mo": ("mo", "mofile"), "gmo": ("mo", "mofile"),
+    "tab": ("omegat", "OmegaTFileTab"),
+    "utf8": ("omegat", "OmegaTFile"),
+    "po": ("po", "pofile"),
+    "pot": ("po", "pofile"),
+    "mo": ("mo", "mofile"),
+    "gmo": ("mo", "mofile"),
     "qm": ("qm", "qmfile"),
     "lang": ("mozilla_lang", "LangStore"),
     "utx": ("utx", "UtxFile"),
     "_wftm": ("wordfast", "WordfastTMFile"),
     "_trados_txt_tm": ("trados", "TradosTxtTmFile"),
     "catkeys": ("catkeys", "CatkeysFile"),
-
     "qph": ("qph", "QphFile"),
     "tbx": ("tbx", "tbxfile"),
     "tmx": ("tmx", "tmxfile"),
     "ts": ("ts2", "tsfile"),
-    "xliff": ("xliff", "xlifffile"), "xlf": ("xliff", "xlifffile"),
+    "xliff": ("xliff", "xlifffile"),
+    "xlf": ("xliff", "xlifffile"),
     "sdlxliff": ("xliff", "xlifffile"),
-
-    # Monolingual formats
-    "ftl": ("l20n", "l20nfile"),
 }
 ###  XXX:  if you add anything here, you must also add it to translate.storage.
 
@@ -64,23 +67,24 @@ _ext is a pseudo extension, that is their is no real extension by that name.
 
 def _examine_txt(storefile):
     """Determine the true filetype for a .txt file"""
-    if isinstance(storefile, six.string_types) and os.path.exists(storefile):
-        storefile = open(storefile, 'rb')
+    if isinstance(storefile, str) and os.path.exists(storefile):
+        storefile = open(storefile, "rb")
     try:
         start = storefile.read(600).strip()
     except AttributeError:
         raise ValueError("Need to read object to determine type")
     # Some encoding magic for Wordfast
     from translate.storage import wordfast
+
     if wordfast.TAB_UTF16 in start.split(b"\n")[0]:
-        encoding = 'utf-16'
+        encoding = "utf-16"
     else:
-        encoding = 'iso-8859-1'
+        encoding = "iso-8859-1"
     start = start.decode(encoding)
-    if '%Wordfast TM' in start:
-        pseudo_extension = '_wftm'
-    elif '<RTF Preamble>' in start:
-        pseudo_extension = '_trados_txt_tm'
+    if "%Wordfast TM" in start:
+        pseudo_extension = "_wftm"
+    elif "<RTF Preamble>" in start:
+        pseudo_extension = "_trados_txt_tm"
     else:
         raise ValueError("Failed to guess file type.")
     storefile.seek(0)
@@ -95,18 +99,18 @@ def _guessextention(storefile):
     characters.  The return value is a file extention.
     """
     start = storefile.read(300).strip()
-    if b'<xliff ' in start:
-        extention = 'xlf'
+    if b"<xliff " in start:
+        extention = "xlf"
     elif b'msgid "' in start:
-        extention = 'po'
-    elif b'%Wordfast TM' in start:
-        extention = 'txt'
-    elif b'<!DOCTYPE TS>' in start:
-        extention = 'ts'
-    elif b'<tmx ' in start:
-        extention = 'tmx'
-    elif b'#UTX' in start:
-        extention = 'utx'
+        extention = "po"
+    elif b"%Wordfast TM" in start:
+        extention = "txt"
+    elif b"<!DOCTYPE TS>" in start:
+        extention = "ts"
+    elif b"<tmx " in start:
+        extention = "tmx"
+    elif b"#UTX" in start:
+        extention = "utx"
     else:
         raise ValueError("Failed to guess file type.")
     storefile.seek(0)
@@ -117,14 +121,16 @@ def _getdummyname(storefile):
     """Provides a dummy name for a file object without a name attribute, by
     guessing the file type.
     """
-    return 'dummy.' + _guessextention(storefile)
+    return "dummy." + _guessextention(storefile)
 
 
 def _getname(storefile):
     """returns the filename"""
     if storefile is None:
-        raise ValueError("This method cannot magically produce a filename when given None as input.")
-    if not isinstance(storefile, six.string_types):
+        raise ValueError(
+            "This method cannot magically produce a filename when given None as input."
+        )
+    if not isinstance(storefile, str):
         if not hasattr(storefile, "name"):
             storefilename = _getdummyname(storefile)
         else:
@@ -134,8 +140,22 @@ def _getname(storefile):
     return storefilename
 
 
-def getclass(storefile, localfiletype=None, ignore=None, classes=None,
-             classes_str=None, hiddenclasses=None):
+@lru_cache(maxsize=128)
+def import_class(module_name, class_name, prefix=None):
+    if prefix:
+        module_name = f"{prefix}.{module_name}"
+    module = import_module(module_name)
+    return getattr(module, class_name)
+
+
+def getclass(
+    storefile,
+    localfiletype=None,
+    ignore=None,
+    classes=None,
+    classes_str=None,
+    hiddenclasses=None,
+):
     """Factory that returns the applicable class for the type of file
     presented.  Specify ignore to ignore some part at the back of the name
     (like .gz).
@@ -146,22 +166,20 @@ def getclass(storefile, localfiletype=None, ignore=None, classes=None,
     if hiddenclasses is None:
         hiddenclasses = _hiddenclasses
     if ignore and storefilename.endswith(ignore):
-        storefilename = storefilename[:-len(ignore)]
+        storefilename = storefilename[: -len(ignore)]
     ext = localfiletype
     if ext is None:
         root, ext = os.path.splitext(storefilename)
-        ext = ext[len(os.path.extsep):].lower()
+        ext = ext[len(os.path.extsep) :].lower()
         decomp = None
         if ext in decompressclass:
             decomp = ext
             root, ext = os.path.splitext(root)
-            ext = ext[len(os.path.extsep):].lower()
+            ext = ext[len(os.path.extsep) :].lower()
         if ext in hiddenclasses:
             guesserfn = hiddenclasses[ext]
             if decomp:
-                _module, _class = decompressclass[decomp]
-                module = __import__(_module, globals(), {}, [])
-                _file = getattr(module, _class)
+                _file = import_class(*decompressclass[decomp])
                 ext = guesserfn(_file(storefile))
             else:
                 ext = guesserfn(storefile)
@@ -170,41 +188,50 @@ def getclass(storefile, localfiletype=None, ignore=None, classes=None,
         if classes:
             storeclass = classes[ext]
         else:
-            _module, _class = classes_str[ext]
-            module = __import__("translate.storage.%s" % _module, globals(), {}, _module)
-            storeclass = getattr(module, _class)
+            storeclass = import_class(*classes_str[ext], "translate.storage")
     except KeyError:
         raise ValueError("Unknown filetype (%s)" % storefilename)
     return storeclass
 
 
-def getobject(storefile, localfiletype=None, ignore=None, classes=None,
-              classes_str=None, hiddenclasses=None):
+def getobject(
+    storefile,
+    localfiletype=None,
+    ignore=None,
+    classes=None,
+    classes_str=None,
+    hiddenclasses=None,
+):
     """Factory that returns a usable object for the type of file presented.
 
-    :type storefile: file or str
+    :type storefile: file or str or TranslationStore
     :param storefile: File object or file name.
 
     Specify ignore to ignore some part at the back of the name (like .gz).
     """
+    if isinstance(storefile, TranslationStore):
+        return storefile
     if classes_str is None:
         classes_str = _classes_str
     if hiddenclasses is None:
         hiddenclasses = _hiddenclasses
-    if isinstance(storefile, six.string_types):
+    if isinstance(storefile, str):
         if os.path.isdir(storefile) or storefile.endswith(os.path.sep):
-            from translate.storage import directory
-            return directory.Directory(storefile)
+            return Directory(storefile)
     storefilename = _getname(storefile)
-    storeclass = getclass(storefile, localfiletype, ignore, classes=classes,
-                          classes_str=classes_str, hiddenclasses=hiddenclasses)
+    storeclass = getclass(
+        storefile,
+        localfiletype,
+        ignore,
+        classes=classes,
+        classes_str=classes_str,
+        hiddenclasses=hiddenclasses,
+    )
     if os.path.exists(storefilename) or not getattr(storefile, "closed", True):
         name, ext = os.path.splitext(storefilename)
-        ext = ext[len(os.path.extsep):].lower()
+        ext = ext[len(os.path.extsep) :].lower()
         if ext in decompressclass:
-            _module, _class = decompressclass[ext]
-            module = __import__(_module, globals(), {}, [])
-            _file = getattr(module, _class)
+            _file = import_class(*decompressclass[ext])
             storefile = _file(storefilename)
         store = storeclass.parsefile(storefile)
     else:
@@ -214,17 +241,34 @@ def getobject(storefile, localfiletype=None, ignore=None, classes=None,
 
 
 supported = [
-    ('Gettext PO file', ['po', 'pot'], ["text/x-gettext-catalog", "text/x-gettext-translation", "text/x-po", "text/x-pot"]),
-    ('XLIFF Translation File', ['xlf', 'xliff', 'sdlxliff'], ["application/x-xliff", "application/x-xliff+xml"]),
-    ('Gettext MO file', ['mo', 'gmo'], ["application/x-gettext-catalog", "application/x-mo"]),
-    ('Qt .qm file', ['qm'], ["application/x-qm"]),
-    ('TBX Glossary', ['tbx'], ['application/x-tbx']),
-    ('TMX Translation Memory', ['tmx'], ["application/x-tmx"]),
-    ('Qt Linguist Translation File', ['ts'], ["application/x-linguist"]),
-    ('Qt Phrase Book', ['qph'], ["application/x-qph"]),
-    ('OmegaT Glossary', ['utf8', 'tab'], ["application/x-omegat-glossary"]),
-    ('UTX Dictionary', ['utx'], ["text/x-utx"]),
-    ('Haiku catkeys file', ['catkeys'], ["application/x-catkeys"]),
+    (
+        "Gettext PO file",
+        ["po", "pot"],
+        [
+            "text/x-gettext-catalog",
+            "text/x-gettext-translation",
+            "text/x-po",
+            "text/x-pot",
+        ],
+    ),
+    (
+        "XLIFF Translation File",
+        ["xlf", "xliff", "sdlxliff"],
+        ["application/x-xliff", "application/x-xliff+xml"],
+    ),
+    (
+        "Gettext MO file",
+        ["mo", "gmo"],
+        ["application/x-gettext-catalog", "application/x-mo"],
+    ),
+    ("Qt .qm file", ["qm"], ["application/x-qm"]),
+    ("TBX Glossary", ["tbx"], ["application/x-tbx"]),
+    ("TMX Translation Memory", ["tmx"], ["application/x-tmx"]),
+    ("Qt Linguist Translation File", ["ts"], ["application/x-linguist"]),
+    ("Qt Phrase Book", ["qph"], ["application/x-qph"]),
+    ("OmegaT Glossary", ["utf8", "tab"], ["application/x-omegat-glossary"]),
+    ("UTX Dictionary", ["utx"], ["text/x-utx"]),
+    ("Haiku catkeys file", ["catkeys"], ["application/x-catkeys"]),
 ]
 
 
