@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2011 Zuza Software Foundation
 #
@@ -23,7 +22,7 @@ This implementation assumes that cpo is working. This should not be used
 directly, but can be used once cpo has been established to work.
 """
 
-#TODO:
+# TODO:
 # - handle headerless PO files better
 # - previous msgid and msgctxt
 # - accept only unicodes everywhere
@@ -31,10 +30,7 @@ directly, but can be used once cpo has been established to work.
 import copy
 import logging
 import re
-import six
 
-from translate.lang import data
-from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage import base, cpo, pocommon
 
@@ -45,14 +41,13 @@ logger = logging.getLogger(__name__)
 lsep = " "
 """Separator for #: entries"""
 
-basic_header = r'''msgid ""
+basic_header = r"""msgid ""
 msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-'''
+"""
 
 
-@six.python_2_unicode_compatible
 class pounit(pocommon.pounit):
     # othercomments = []      #   # this is another comment
     # automaticcomments = []  #   #. comment extracted from the source code
@@ -61,21 +56,21 @@ class pounit(pocommon.pounit):
     # prev_msgid = []         #
     # prev_msgid_plural = []  #
     # typecomments = []       #   #, fuzzy
-    # msgidcomment = u""      #   _: within msgid
+    # msgidcomment = ""      #   _: within msgid
     # msgctxt
     # msgid = []
     # msgstr = []
 
     # Our homegrown way to indicate what must be copied in a shallow
     # fashion
-    __shallow__ = ['_store']
+    __shallow__ = ["_store"]
 
     def __init__(self, source=None, **kwargs):
-        pocommon.pounit.__init__(self, source)
+        super().__init__(source)
         self._initallcomments(blankall=True)
-        self._msgctxt = u""
+        self._msgctxt = ""
 
-        self.target = u""
+        self.target = ""
 
     def _initallcomments(self, blankall=False):
         """Initialises allcomments"""
@@ -84,7 +79,7 @@ class pounit(pocommon.pounit):
             self.automaticcomments = []
             self.sourcecomments = []
             self.typecomments = []
-            self.msgidcomment = u""
+            self.msgidcomment = ""
 
     @property
     def source(self):
@@ -93,20 +88,14 @@ class pounit(pocommon.pounit):
     @source.setter
     def source(self, source):
         self._rich_source = None
-        source = data.forceunicode(source or u"")
-        source = source or u""
+        source = source or ""
         if isinstance(source, multistring):
             self._source = source
-        elif isinstance(source, six.text_type):
+        elif isinstance(source, str):
             self._source = source
         else:  # If it is unicode, list or dict.
             self._source = multistring(source)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     @property
     def target(self):
         """Returns the unescaped msgstr"""
@@ -125,25 +114,22 @@ class pounit(pocommon.pounit):
             if len(target) == 1:
                 self._target = target[0]
             else:
-                raise ValueError("po msgid element has no plural but msgstr"
-                                 "has %d elements (%s)" % (len(target), target))
+                raise ValueError(
+                    "po msgid element has no plural but msgstr"
+                    "has %d elements (%s)" % (len(target), target)
+                )
         else:
             self._target = target
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
-
     def getnotes(self, origin=None):
         """Return comments based on origin value (programmer, developer, source code and translator)"""
         if origin is None:
-            comments = u"\n".join(self.othercomments)
-            comments += u"\n".join(self.automaticcomments)
+            comments = "\n".join(self.othercomments)
+            comments += "\n".join(self.automaticcomments)
         elif origin == "translator":
-            comments = u"\n".join(self.othercomments)
+            comments = "\n".join(self.othercomments)
         elif origin in ["programmer", "developer", "source code"]:
-            comments = u"\n".join(self.automaticcomments)
+            comments = "\n".join(self.automaticcomments)
         else:
             raise ValueError("Comment type not valid")
         return comments
@@ -153,15 +139,14 @@ class pounit(pocommon.pounit):
         # ignore empty strings and strings without non-space characters
         if not (text and text.strip()):
             return
-        text = data.forceunicode(text)
         commentlist = self.othercomments
         autocomments = False
         if origin in ["programmer", "developer", "source code"]:
             autocomments = True
             commentlist = self.automaticcomments
-        if text.endswith(u'\n'):
+        if text.endswith("\n"):
             text = text[:-1]
-        newcomments = text.split(u"\n")
+        newcomments = text.split("\n")
         if position == "append":
             newcomments = commentlist + newcomments
         elif position == "prepend":
@@ -183,7 +168,7 @@ class pounit(pocommon.pounit):
         # self.__shallow__
         shallow = set(self.__shallow__)
         # Make deep copies of all members which are not in shallow
-        for key, value in six.iteritems(self.__dict__):
+        for key, value in self.__dict__.items():
             if key not in shallow:
                 setattr(new_unit, key, copy.deepcopy(value))
         # Make shallow copies of all members which are in shallow
@@ -218,16 +203,7 @@ class pounit(pocommon.pounit):
         """
 
         def mergelists(list1, list2, split=False):
-            # Decode where necessary (either all bytestrings or all unicode)
-            if six.text_type in [type(item) for item in list2] + [type(item) for item in list1]:
-                for position, item in enumerate(list1):
-                    if isinstance(item, bytes):
-                        list1[position] = item.decode("utf-8")
-                for position, item in enumerate(list2):
-                    if isinstance(item, bytes):
-                        list2[position] = item.decode("utf-8")
-
-            #Determine the newline style of list2
+            # Determine the newline style of list2
             lineend = ""
             if list2 and list2[0]:
                 for candidate in ["\n", "\r", "\n\r"]:
@@ -236,7 +212,7 @@ class pounit(pocommon.pounit):
                 if not lineend:
                     lineend = ""
 
-            #Split if directed to do so:
+            # Split if directed to do so:
             if split:
                 splitlist1 = []
                 splitlist2 = []
@@ -246,7 +222,7 @@ class pounit(pocommon.pounit):
                     splitlist2.extend(item.split())
                 list1.extend([item for item in splitlist2 if item not in splitlist1])
             else:
-                #Normal merge, but conform to list1 newline style
+                # Normal merge, but conform to list1 newline style
                 if list1 != list2:
                     for item in list2:
                         item = item.rstrip(lineend)
@@ -255,7 +231,7 @@ class pounit(pocommon.pounit):
                             list1.append(item)
 
         if not isinstance(otherpo, pounit):
-            super(pounit, self).merge(otherpo, overwrite, comments)
+            super().merge(otherpo, overwrite, comments)
             return
         if comments:
             mergelists(self.othercomments, otherpo.othercomments)
@@ -264,14 +240,19 @@ class pounit(pocommon.pounit):
                 # We don't bring across otherpo.automaticcomments as we consider ourself
                 # to be the the authority.  Same applies to otherpo.msgidcomments
                 mergelists(self.automaticcomments, otherpo.automaticcomments)
-#                mergelists(self.msgidcomments, otherpo.msgidcomments) #XXX?
+                #                mergelists(self.msgidcomments, otherpo.msgidcomments) #XXX?
                 mergelists(self.sourcecomments, otherpo.sourcecomments, split=True)
         if not self.istranslated() or overwrite:
             # Remove kde-style comments from the translation (if any). XXX - remove
             if pocommon.extract_msgid_comment(otherpo.target):
-                otherpo.target = otherpo.target.replace('_: ' + otherpo._extract_msgidcomments() + '\n', '')
+                otherpo.target = otherpo.target.replace(
+                    "_: " + otherpo._extract_msgidcomments() + "\n", ""
+                )
             self.target = otherpo.target
-            if self.source != otherpo.source or self.getcontext() != otherpo.getcontext():
+            if (
+                self.source != otherpo.source
+                or self.getcontext() != otherpo.getcontext()
+            ):
                 self.markfuzzy()
             else:
                 self.markfuzzy(otherpo.isfuzzy())
@@ -283,20 +264,32 @@ class pounit(pocommon.pounit):
                 self.markfuzzy()
 
     def isheader(self):
-        #TODO: fix up nicely
+        # TODO: fix up nicely
         return not self.getid() and len(self.target) > 0
 
     def isblank(self):
         if self.isheader() or self.msgidcomment:
             return False
-        if (self._msgidlen() == 0) and (self._msgstrlen() == 0) and len(self._msgctxt) == 0:
+        if (
+            (self._msgidlen() == 0)
+            and (self._msgstrlen() == 0)
+            and len(self._msgctxt) == 0
+        ):
             return True
         return False
 
     def hastypecomment(self, typecomment):
         """Check whether the given type comment is present"""
         # check for word boundaries properly by using a regular expression...
-        return sum(map(lambda tcline: len(re.findall("\\b%s\\b" % typecomment, tcline)), self.typecomments)) != 0
+        return (
+            sum(
+                map(
+                    lambda tcline: len(re.findall("\\b%s\\b" % typecomment, tcline)),
+                    self.typecomments,
+                )
+            )
+            != 0
+        )
 
     def hasmarkedcomment(self, commentmarker):
         """Check whether the given comment marker is present as # (commentmarker) ..."""
@@ -313,11 +306,16 @@ class pounit(pocommon.pounit):
                 self.typecomments.append("#, %s\n" % typecomment)
             else:
                 # this should handle word boundaries properly ...
-                typecomments = map(lambda tcline: re.sub("\\b%s\\b[ \t,]*" % typecomment, "", tcline), self.typecomments)
-                self.typecomments = filter(lambda tcline: tcline.strip() != "#,", typecomments)
+                typecomments = map(
+                    lambda tcline: re.sub("\\b%s\\b[ \t,]*" % typecomment, "", tcline),
+                    self.typecomments,
+                )
+                self.typecomments = filter(
+                    lambda tcline: tcline.strip() != "#,", typecomments
+                )
 
     def istranslated(self):
-        return super(pounit, self).istranslated() and not self.isobsolete()
+        return super().istranslated() and not self.isobsolete()
 
     def istranslatable(self):
         return not (self.isheader() or self.isblank() or self.isobsolete())
@@ -332,7 +330,7 @@ class pounit(pocommon.pounit):
         """Makes this unit obsolete"""
         self.sourcecomments = []
         self.automaticcomments = []
-        super(pounit, self).makeobsolete()
+        super().makeobsolete()
 
     def hasplural(self):
         """returns whether this pounit contains plural strings..."""
@@ -351,7 +349,7 @@ class pounit(pocommon.pounit):
         return: A list of the locations with '#: ' stripped
 
         """
-        #TODO: rename to .locations
+        # TODO: rename to .locations
         return self.sourcecomments
 
     def addlocation(self, location):
@@ -378,8 +376,7 @@ class pounit(pocommon.pounit):
         return self._msgctxt + self.msgidcomment
 
     def setcontext(self, context):
-        context = data.forceunicode(context or u"")
-        self._msgctxt = context
+        self._msgctxt = context or ""
 
     def getid(self):
         """Returns a unique identifier for this unit."""
@@ -388,12 +385,12 @@ class pounit(pocommon.pounit):
         # the msgid. For generation of .mo files, we might want to use this
         # code to generate the entry for the hash table, but for now, it is
         # commented out for conformance to gettext.
-#        id = '\0'.join(self.source.strings)
+        #        id = '\0'.join(self.source.strings)
         id = self.source
         if self.msgidcomment:
-            id = u"_: %s\n%s" % (context, id)
+            id = f"_: {context}\n{id}"
         elif context:
-            id = u"%s\04%s" % (context, id)
+            id = f"{context}\04{id}"
         return id
 
     @classmethod
@@ -406,7 +403,7 @@ class pounit(pocommon.pounit):
         elif isinstance(unit, pocommon.pounit):
             newunit = cls(unit.source)
             newunit.target = unit.target
-            #context
+            # context
             newunit.msgidcomment = unit._extract_msgidcomments()
             if not newunit.msgidcomment:
                 newunit.setcontext(unit.getcontext())
@@ -423,7 +420,7 @@ class pounit(pocommon.pounit):
             newunit.markfuzzy(unit.isfuzzy())
             if unit.isobsolete():
                 newunit.makeobsolete()
-            for tc in ['python-format', 'c-format', 'php-format']:
+            for tc in ["python-format", "c-format", "php-format"]:
                 if unit.hastypecomment(tc):
                     newunit.settypecomment(tc)
                     break
@@ -456,18 +453,20 @@ class pofile(pocommon.pofile):
         self._cpo_store = cpo.pofile(noheader=True)
         for unit in self.units:
             if not unit.isblank():
-                self._cpo_store.addunit(cpo.pofile.UnitClass.buildfromunit(unit, self.encoding))
+                self._cpo_store.addunit(
+                    cpo.pofile.UnitClass.buildfromunit(unit, self.encoding)
+                )
         if not self._cpo_store.header():
-            #only add a temporary header
+            # only add a temporary header
             self._cpo_store.makeheader(charset=self.encoding, encoding="8bit")
 
     def parse(self, input):
         """Parses the given file or file source string."""
         try:
-            if hasattr(input, 'name'):
+            if hasattr(input, "name"):
                 self.filename = input.name
-            elif not getattr(self, 'filename', ''):
-                self.filename = ''
+            elif not getattr(self, "filename", ""):
+                self.filename = ""
             self.units = []
             self._cpo_store = cpo.pofile(input, noheader=True)
             self._build_self_from_cpo()
@@ -488,6 +487,7 @@ class pofile(pocommon.pofile):
         def addcomment(thepo):
             thepo.msgidcomment = " ".join(thepo.getlocations())
             markedpos.append(thepo)
+
         for thepo in self.units:
             id = thepo.getid()
             if thepo.isheader() and not thepo.getlocations():
@@ -510,16 +510,17 @@ class pofile(pocommon.pofile):
                     if not thepo._msgctxt == id_dict[id]._msgctxt:
                         uniqueunits.append(thepo)
                     else:
-                        logger.warn(
+                        logger.warning(
                             "Duplicate unit found with msgctx of '%s' and source '%s'",
                             thepo._msgctxt,
-                            thepo.source)
+                            thepo.source,
+                        )
             else:
                 if not id:
                     if duplicatestyle == "merge":
                         addcomment(thepo)
                     else:
-                        thepo._msgctxt += u" ".join(thepo.getlocations())
+                        thepo._msgctxt += " ".join(thepo.getlocations())
                 id_dict[id] = thepo
                 uniqueunits.append(thepo)
         self.units = uniqueunits
@@ -529,7 +530,7 @@ class pofile(pocommon.pofile):
         self._cpo_store = cpo.pofile(encoding=self.encoding, noheader=True)
         try:
             self._build_cpo_from_self()
-        except UnicodeEncodeError as e:
+        except UnicodeEncodeError:
             self.encoding = "utf-8"
             self.updateheader(add=True, Content_Type="text/plain; charset=UTF-8")
             self._build_cpo_from_self()
