@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2011 Zuza Software Foundation
 #
@@ -20,7 +19,6 @@
 """class that handles all header functions for a header in a po file"""
 
 import re
-import six
 import time
 from collections import OrderedDict
 
@@ -66,8 +64,7 @@ def tzstring():
     hours, minutes = time.gmtime(abs(tzoffset))[3:5]
     if tzoffset > 0:
         hours *= -1
-    tz = str("%+d" % hours).zfill(3) + str(minutes).zfill(2)
-    return tz
+    return str("%+d" % hours).zfill(3) + str(minutes).zfill(2)
 
 
 def update(existing, add=False, **kwargs):
@@ -94,7 +91,7 @@ def update(existing, add=False, **kwargs):
             removed.append(key)
         elif add and key in fixedargs:
             headerargs[key] = fixedargs.pop(key)
-    for key, value in six.iteritems(existing):
+    for key, value in existing.items():
         if key not in removed:
             headerargs[key] = value
     if add:
@@ -103,7 +100,7 @@ def update(existing, add=False, **kwargs):
     return headerargs
 
 
-class poheader(object):
+class poheader:
     """This class implements functionality for manipulation of po file headers.
     This class is a mix-in class and useless on its own. It must be used from
     all classes which represent a po file
@@ -128,25 +125,27 @@ class poheader(object):
         "X-Merge-On",
     ]
 
-    def init_headers(self, charset='UTF-8', encoding='8bit', **kwargs):
+    def init_headers(self, charset="UTF-8", encoding="8bit", **kwargs):
         """sets default values for po headers"""
-        #FIXME: we need to allow at least setting target language, pluralforms and generator
+        # FIXME: we need to allow at least setting target language, pluralforms and generator
         headerdict = self.makeheaderdict(charset=charset, encoding=encoding, **kwargs)
         self.updateheader(add=True, **headerdict)
         return self.header()
 
-    def makeheaderdict(self,
-                       charset="CHARSET",
-                       encoding="ENCODING",
-                       project_id_version=None,
-                       pot_creation_date=None,
-                       po_revision_date=None,
-                       last_translator=None,
-                       language_team=None,
-                       mime_version=None,
-                       plural_forms=None,
-                       report_msgid_bugs_to=None,
-                       **kwargs):
+    def makeheaderdict(
+        self,
+        charset="CHARSET",
+        encoding="ENCODING",
+        project_id_version=None,
+        pot_creation_date=None,
+        po_revision_date=None,
+        last_translator=None,
+        language_team=None,
+        mime_version=None,
+        plural_forms=None,
+        report_msgid_bugs_to=None,
+        **kwargs,
+    ):
         """Create a header dictionary with useful defaults.
 
         pot_creation_date can be None (current date) or a value (datetime or string)
@@ -161,7 +160,9 @@ class poheader(object):
         if pot_creation_date is None or pot_creation_date is True:
             pot_creation_date = time.strftime("%Y-%m-%d %H:%M") + tzstring()
         if isinstance(pot_creation_date, time.struct_time):
-            pot_creation_date = time.strftime("%Y-%m-%d %H:%M", pot_creation_date) + tzstring()
+            pot_creation_date = (
+                time.strftime("%Y-%m-%d %H:%M", pot_creation_date) + tzstring()
+            )
         if po_revision_date is None:
             po_revision_date = "YEAR-MO-DA HO:MI+ZONE"
         elif po_revision_date is False:
@@ -169,7 +170,9 @@ class poheader(object):
         elif po_revision_date is True:
             po_revision_date = time.strftime("%Y-%m-%d %H:%M") + tzstring()
         if isinstance(po_revision_date, time.struct_time):
-            po_revision_date = time.strftime("%Y-%m-%d %H:%M", po_revision_date) + tzstring()
+            po_revision_date = (
+                time.strftime("%Y-%m-%d %H:%M", po_revision_date) + tzstring()
+            )
         if last_translator is None:
             last_translator = "FULL NAME <EMAIL@ADDRESS>"
         if language_team is None:
@@ -230,16 +233,22 @@ class poheader(object):
         else:
             headeritems = update(self.parseheader(), add, **kwargs)
             keys = headeritems.keys()
-            if "Content-Type" not in keys or "charset=CHARSET" in headeritems["Content-Type"]:
+            if (
+                "Content-Type" not in keys
+                or "charset=CHARSET" in headeritems["Content-Type"]
+            ):
                 headeritems["Content-Type"] = "text/plain; charset=UTF-8"
-            if "Content-Transfer-Encoding" not in keys or "ENCODING" in headeritems["Content-Transfer-Encoding"]:
+            if (
+                "Content-Transfer-Encoding" not in keys
+                or "ENCODING" in headeritems["Content-Transfer-Encoding"]
+            ):
                 headeritems["Content-Transfer-Encoding"] = "8bit"
             headerString = ""
             for key, value in headeritems.items():
                 if value is not None:
-                    headerString += "%s: %s\n" % (key, value)
+                    headerString += f"{key}: {value}\n"
             header.target = headerString
-            header.markfuzzy(False)    # TODO: check why we do this?
+            header.markfuzzy(False)  # TODO: check why we do this?
         return header
 
     def _insert_header(self, header):
@@ -253,7 +262,7 @@ class poheader(object):
     def getheaderplural(self):
         """Returns the nplural and plural values from the header."""
         header = self.parseheader()
-        pluralformvalue = header.get('Plural-Forms', None)
+        pluralformvalue = header.get("Plural-Forms", None)
         if pluralformvalue is None:
             return None, None
         nplural = re.findall("nplurals=(.+?);", pluralformvalue)
@@ -270,9 +279,11 @@ class poheader(object):
 
     def updateheaderplural(self, nplurals, plural):
         """Update the Plural-Form PO header."""
-        if isinstance(nplurals, six.string_types):
+        if isinstance(nplurals, str):
             nplurals = int(nplurals)
-        self.updateheader(add=True, Plural_Forms="nplurals=%d; plural=%s;" % (nplurals, plural))
+        self.updateheader(
+            add=True, Plural_Forms="nplurals=%d; plural=%s;" % (nplurals, plural)
+        )
 
     def gettargetlanguage(self):
         """Return the target language based on information in the header.
@@ -283,23 +294,26 @@ class poheader(object):
           3. Analysing the 'Language-Team' entry.
         """
         header = self.parseheader()
-        lang = header.get('Language', None)
+        lang = header.get("Language", None)
         if lang is not None:
             from translate.lang.data import langcode_ire
+
             if langcode_ire.match(lang):
                 return lang
             else:
                 lang = None
-        if 'X-Poedit-Language' in header:
+        if "X-Poedit-Language" in header:
             from translate.lang import poedit
-            language = header.get('X-Poedit-Language')
-            country = header.get('X-Poedit-Country')
+
+            language = header.get("X-Poedit-Language")
+            country = header.get("X-Poedit-Country")
             return poedit.isocode(language, country)
-        if 'Language-Code' in header:  # Used in Plone files
-            return header.get('Language-Code')
-        if 'Language-Team' in header:
+        if "Language-Code" in header:  # Used in Plone files
+            return header.get("Language-Code")
+        if "Language-Team" in header:
             from translate.lang.team import guess_language
-            return guess_language(header.get('Language-Team'))
+
+            return guess_language(header.get("Language-Team"))
         return None
 
     def settargetlanguage(self, lang):
@@ -310,8 +324,10 @@ class poheader(object):
         :param lang: the new target language code
         :type lang: str
         """
-        if isinstance(lang, six.string_types) and len(lang) > 1:
-            self.updateheader(add=True, Language=lang, X_Poedit_Language=None, X_Poedit_Country=None)
+        if isinstance(lang, str) and len(lang) > 1:
+            self.updateheader(
+                add=True, Language=lang, X_Poedit_Language=None, X_Poedit_Country=None
+            )
 
     def getprojectstyle(self):
         """Return the project based on information in the header.
@@ -324,24 +340,24 @@ class poheader(object):
           5. Analyse the file itself (not yet implemented)
         """
         header = self.parseheader()
-        project = header.get('X-Project-Style', None)
+        project = header.get("X-Project-Style", None)
         if project is not None:
             return project
-        bug_address = header.get('Report-Msgid-Bugs-To', None)
+        bug_address = header.get("Report-Msgid-Bugs-To", None)
         if bug_address is not None:
-            if 'bugzilla.gnome.org' in bug_address:
-                return 'gnome'
-            if 'bugs.kde.org' in bug_address:
-                return 'kde'
-        accelerator = header.get('X-Accelerator-Marker', None)
+            if "bugzilla.gnome.org" in bug_address:
+                return "gnome"
+            if "bugs.kde.org" in bug_address:
+                return "kde"
+        accelerator = header.get("X-Accelerator-Marker", None)
         if accelerator is not None:
             if accelerator == "~":
                 return "openoffice"
             elif accelerator == "&":
                 return "mozilla"
-        project_id = header.get('Project-Id-Version', None)
+        project_id = header.get("Project-Id-Version", None)
         if project_id is not None:
-            if 'gnome' in project_id.lower():
+            if "gnome" in project_id.lower():
                 return "gnome"
         # TODO Call some project guessing code and probably move all of the above there also
         return None
@@ -363,9 +379,19 @@ class poheader(object):
         """
 
         newvalues = otherstore.parseheader()
-        retain_list = ("Project-Id-Version", "PO-Revision-Date", "Last-Translator",
-                       "Language-Team", "Plural-Forms")
-        retain = dict((key, newvalues[key]) for key in retain_list if newvalues.get(key, None) and newvalues[key] != default_header.get(key, None))
+        retain_list = (
+            "Project-Id-Version",
+            "PO-Revision-Date",
+            "Last-Translator",
+            "Language-Team",
+            "Plural-Forms",
+        )
+        retain = {
+            key: newvalues[key]
+            for key in retain_list
+            if newvalues.get(key, None)
+            and newvalues[key] != default_header.get(key, None)
+        }
         self.updateheader(**retain)
 
     def updatecontributor(self, name, email=None):
@@ -379,9 +405,9 @@ class poheader(object):
         contribexists = False
         incontrib = False
         outcontrib = False
-        for line in header.getnotes("translator").split('\n'):
+        for line in header.getnotes("translator").split("\n"):
             line = line.strip()
-            if line == u"FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.":
+            if line == "FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.":
                 incontrib = True
                 continue
             if author_re.match(line):
@@ -407,17 +433,17 @@ class poheader(object):
                 if year in line:
                     break
                 else:
-                    #The contributor is there, but not for this year
-                    if line[-1] == '.':
+                    # The contributor is there, but not for this year
+                    if line[-1] == ".":
                         line = line[:-1]
-                    contriblines[i] = "%s, %s." % (line, year)
+                    contriblines[i] = f"{line}, {year}."
 
         if not contribexists:
             # Add a new contributor
             if email:
-                contriblines.append("%s <%s>, %s." % (name, email, year))
+                contriblines.append(f"{name} <{email}>, {year}.")
             else:
-                contriblines.append("%s, %s." % (name, year))
+                contriblines.append(f"{name}, {year}.")
 
         header.removenotes()
         header.addnote("\n".join(prelines))
@@ -436,6 +462,6 @@ class poheader(object):
         for (key, value) in headeritems.items():
             if value is None:
                 continue
-            headervalue += "%s: %s\n" % (key, value)
+            headervalue += f"{key}: {value}\n"
         headerpo.target = headervalue
         return headerpo
