@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2015 Zuza Software Foundation
 # Copyright 2015 Sarah Hale
@@ -22,9 +21,7 @@
 
 from lxml import etree
 
-from translate.lang import data
-from translate.misc.deprecation import deprecated
-from translate.misc.xml_helpers import setXMLspace, reindent
+from translate.misc.xml_helpers import setXMLspace
 from translate.storage import lisa
 from translate.storage.placeables import general
 
@@ -53,18 +50,13 @@ class RESXUnit(lisa.LISAunit):
     def source(self):
         return self.target
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     @property
     def target(self):
         targetnode = self._gettargetnode()
         if targetnode is None:
             etree.SubElement(self.xmlelement, self.namespaced("value"))
             return None
-        return data.forceunicode(targetnode.text) or u""
+        return targetnode.text or ""
 
     @target.setter
     def target(self, target):
@@ -75,22 +67,10 @@ class RESXUnit(lisa.LISAunit):
             return
         targetnode = self._gettargetnode()
         targetnode.clear()
-        targetnode.text = data.forceunicode(target) or u""
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def settarget(self, target):
-        self.target = target
+        targetnode.text = target or ""
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in the appropriate "comment" tag"""
-        if isinstance(text, bytes):
-            text = text.decode("utf-8")
         current_notes = self.getnotes(origin)
         self.removenotes(origin)
         note = etree.SubElement(self.xmlelement, self.namespaced("comment"))
@@ -106,14 +86,14 @@ class RESXUnit(lisa.LISAunit):
         if note.text:
             # Correct the indent of <comment> by updating the tail of
             # the preceding <value> element
-            targetnode = self._gettargetnode()
+            self._gettargetnode()
 
     def getnotes(self, origin=None):
         comments = []
         notenode = self.xmlelement.find(self.namespaced("comment"))
         if notenode is not None and notenode.text is not None:
             comments.append(notenode.text)
-        return '\n'.join(comments)
+        return "\n".join(comments)
 
     def removenotes(self, origin=None):
         note = self.xmlelement.find(self.namespaced("comment"))
@@ -121,9 +101,7 @@ class RESXUnit(lisa.LISAunit):
             self.xmlelement.remove(note)
 
     def setid(self, value):
-        if id is None:
-            return False
-        else:
+        if id is not None:
             self.xmlelement.set("name", value)
 
     def getid(self):
@@ -133,7 +111,7 @@ class RESXUnit(lisa.LISAunit):
         return [self.getid()]
 
     def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
-        super(RESXUnit, self).merge(otherunit, overwrite, comments)
+        super().merge(otherunit, overwrite, comments)
         if otherunit.isfuzzy():
             self.markfuzzy()
 
@@ -148,7 +126,7 @@ class RESXFile(lisa.LISAfile):
     rootNode = "root"
     # We will switch out .body to fit with the context we are working on
     bodyNode = ""
-    XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
+    XMLskeleton = """<?xml version="1.0" encoding="utf-8"?>
 <root>
   <xsd:schema id="root" xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
     <xsd:import namespace="http://www.w3.org/XML/1998/namespace" />
@@ -209,11 +187,14 @@ class RESXFile(lisa.LISAfile):
     <value>System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
   </resheader>
 </root>
-'''
-    namespace = ''
+"""
+    XMLindent = {"indent": "  ", "max_level": 4}
+    # Use same header as Visual Studio
+    XMLdoublequotes = True
+    namespace = ""
 
     def __init__(self, *args, **kwargs):
-        lisa.LISAfile.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._messagenum = 0
 
     def initbody(self):
@@ -224,11 +205,11 @@ class RESXFile(lisa.LISAfile):
 
     def addunit(self, unit, new=True):
         """Adds the given unit to the body node."""
-        super(RESXFile, self).addunit(unit, new)
+        super().addunit(unit, new)
         setXMLspace(unit.xmlelement, "preserve")
         if unit.getid() is None:
             self._messagenum += 1
-            unit.setid(u"%s" % unit.source.strip(' '))
+            unit.setid("%s" % unit.source.strip(" "))
         # adjust the current and previous elements for new ones;
         # otherwise they will not be indented correctly.
         if new:
@@ -237,17 +218,11 @@ class RESXFile(lisa.LISAfile):
                 # this is the first element; adjust root.
                 # should not happen in a ResX file prepared by Visual Studio
                 # since it includes an inline XSD plus resheader at all times.
-                self.body.text = u"\n  "
+                self.body.text = "\n  "
             # adjust the indent of the following <value> element
-            unit.xmlelement.text = u"\n    "
+            unit.xmlelement.text = "\n    "
         return unit
 
-    def serialize(self, out=None):
-        root = self.document.getroot()
-        reindent(root, indent="  ", max_level=4)
-        # Use same header as Visual Studio
-        out.write(b'<?xml version="1.0" encoding="utf-8"?>\n')
-        content = etree.tostring(root, pretty_print=False, xml_declaration=False,
-                                 encoding='utf-8')
+    def serialize_hook(self, treestring):
         # Additional space on empty tags same as Visual Studio
-        out.write(content.replace(b'/>', b' />'))
+        return treestring.replace(b"/>", b" />")
