@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -27,21 +26,43 @@ Supported formats are
 """
 
 import re
-import six
 
-from translate.misc.deprecation import deprecated
 from translate.storage import base
 
 
 dokuwiki = []
-dokuwiki.append(("Dokuwiki heading", re.compile(r"( ?={2,6}[\s]*)(.+)"), re.compile(r"([\s]*={2,6}[\s]*)$")))
-dokuwiki.append(("Dokuwiki bullet", re.compile(r"([\s]{2,}\*[\s]*)(.+)"), re.compile(r"[\s]+$")))
-dokuwiki.append(("Dokuwiki numbered item", re.compile(r"([\s]{2,}-[\s]*)(.+)"), re.compile(r"[\s]+$")))
+dokuwiki.append(
+    (
+        "Dokuwiki heading",
+        re.compile(r"( ?={2,6}[\s]*)(.+)"),
+        re.compile(r"([\s]*={2,6}[\s]*)$"),
+    )
+)
+dokuwiki.append(
+    ("Dokuwiki bullet", re.compile(r"([\s]{2,}\*[\s]*)(.+)"), re.compile(r"[\s]+$"))
+)
+dokuwiki.append(
+    (
+        "Dokuwiki numbered item",
+        re.compile(r"([\s]{2,}-[\s]*)(.+)"),
+        re.compile(r"[\s]+$"),
+    )
+)
 
 mediawiki = []
-mediawiki.append(("MediaWiki heading", re.compile(r"(={1,5}[\s]*)(.+)"), re.compile(r"([\s]*={1,5}[\s]*)$")))
-mediawiki.append(("MediaWiki bullet", re.compile(r"(\*+[\s]*)(.+)"), re.compile(r"[\s]+$")))
-mediawiki.append(("MediaWiki numbered item", re.compile(r"(#+[\s]*)(.+)"), re.compile(r"[\s]+$")))
+mediawiki.append(
+    (
+        "MediaWiki heading",
+        re.compile(r"(={1,5}[\s]*)(.+)"),
+        re.compile(r"([\s]*={1,5}[\s]*)$"),
+    )
+)
+mediawiki.append(
+    ("MediaWiki bullet", re.compile(r"(\*+[\s]*)(.+)"), re.compile(r"[\s]+$"))
+)
+mediawiki.append(
+    ("MediaWiki numbered item", re.compile(r"(#+[\s]*)(.+)"), re.compile(r"[\s]+$"))
+)
 
 flavours = {
     "dokuwiki": dokuwiki,
@@ -51,13 +72,12 @@ flavours = {
 }
 
 
-@six.python_2_unicode_compatible
 class TxtUnit(base.TranslationUnit):
     """This class represents a block of text from a text file"""
 
     def __init__(self, source="", **kwargs):
         """Construct the txtunit"""
-        super(TxtUnit, self).__init__(source)
+        super().__init__(source)
         # Note that source and target are equivalent for monolingual units.
         self.source = source
         self.pretext = ""
@@ -66,12 +86,7 @@ class TxtUnit(base.TranslationUnit):
 
     def __str__(self):
         """Convert a txt unit to a string"""
-        return u"".join([self.pretext, self.source, self.posttext])
-
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
+        return "".join([self.pretext, self.source, self.posttext])
 
     @property
     def target(self):
@@ -84,11 +99,6 @@ class TxtUnit(base.TranslationUnit):
         self._rich_target = None
         self.source = target
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
-
     def addlocation(self, location):
         self.location.append(location)
 
@@ -101,10 +111,9 @@ class TxtFile(base.TranslationStore):
 
     UnitClass = TxtUnit
 
-    def __init__(self, inputfile=None, flavour=None, no_segmentation=False,
-                 **kwargs):
-        super(TxtFile, self).__init__(**kwargs)
-        self.filename = getattr(inputfile, 'name', '')
+    def __init__(self, inputfile=None, flavour=None, no_segmentation=False, **kwargs):
+        super().__init__(**kwargs)
+        self.filename = getattr(inputfile, "name", "")
         self.flavour = flavours.get(flavour, [])
         self.no_segmentation = no_segmentation
         if inputfile is not None:
@@ -114,8 +123,7 @@ class TxtFile(base.TranslationStore):
     def parse(self, lines):
         """Read in text lines and create txtunits from the blocks of text"""
         if self.no_segmentation:
-            self.addsourceunit("".join([line.decode(self.encoding)
-                                        for line in lines]))
+            self.addsourceunit("".join([line.decode(self.encoding) for line in lines]))
             return
         block = []
         current_line = 0
@@ -133,7 +141,7 @@ class TxtFile(base.TranslationStore):
                     postmatch = postre.search(source)
                     if postmatch:
                         posttext = postmatch.group()
-                        source = source[:postmatch.start()]
+                        source = source[: postmatch.start()]
                     block.append(source)
                     isbreak = True
                     break
@@ -156,5 +164,5 @@ class TxtFile(base.TranslationStore):
     def serialize(self, out):
         for idx, unit in enumerate(self.units):
             if idx > 0:
-                out.write(b'\n\n')
-            out.write(six.text_type(unit).encode(self.encoding))
+                out.write(b"\n\n")
+            out.write(str(unit).encode(self.encoding))
