@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
 #
@@ -35,8 +34,6 @@ state values correspond to similar states. For example state 0 should be
 define similar states.
 """
 
-import six
-
 
 class StateEnum:
     """Only contains the constants for default states."""
@@ -52,8 +49,7 @@ class StateEnum:
     MAX = 127
 
 
-class State(object):
-
+class State:
     def __init__(self, name, enter_action=None, leave_action=None):
         self.name = name
         self.enter_action = enter_action
@@ -77,13 +73,12 @@ class State(object):
 
 
 class UnitState(State):
-
     def __init__(self, name, state_value):
         self.state_value = state_value
-        super(UnitState, self).__init__(name, self._enter)
+        super().__init__(name, self._enter)
 
     def __repr__(self):
-        return '<UnitState name=%s value=%d>' % (self.name, self.state_value)
+        return "<UnitState name=%s value=%d>" % (self.name, self.state_value)
 
     def _enter(self, unit):
         unit.set_state_n(self.state_value)
@@ -102,19 +97,16 @@ class TransitionError(WorkflowError):
 
 
 class InvalidStateObjectError(WorkflowError):
-
     def __init__(self, obj):
-        super(InvalidStateObjectError, self).__init__('Invalid state object: %s' % (obj))
+        super().__init__("Invalid state object: %s" % (obj))
 
 
 class StateNotInWorkflowError(Exception):
-
     def __init__(self, state):
-        super(StateNotInWorkflowError, self).__init__(
-            'State not in workflow: %s' % (state))
+        super().__init__("State not in workflow: %s" % (state))
 
 
-class Workflow(object):
+class Workflow:
 
     # INITIALISERS #
     def __init__(self, wf_obj=None):
@@ -127,17 +119,19 @@ class Workflow(object):
     # ACCESSORS #
     def _get_edges(self):
         return list(self._edges)
+
     edges = property(_get_edges)
 
     def _get_states(self):
         return list(self._states)
+
     states = property(_get_states)
 
     # METHODS #
     def add_edge(self, from_state, to_state):
-        if isinstance(from_state, six.string_types):
+        if isinstance(from_state, str):
             from_state = self.get_state_by_name(from_state)
-        if isinstance(to_state, six.string_types):
+        if isinstance(to_state, str):
             to_state = self.get_state_by_name(to_state)
         for s in (from_state, to_state):
             if s not in self.states:
@@ -151,7 +145,7 @@ class Workflow(object):
         if not isinstance(state, State):
             raise InvalidStateObjectError(state)
         if state in self.states:
-            raise ValueError('State already in workflow: %s' % (state))
+            raise ValueError("State already in workflow: %s" % (state))
         self._states.append(state)
         if self._initial_state is None:
             self._initial_state = state
@@ -182,7 +176,7 @@ class Workflow(object):
         ``enter`` method is still called. For edge transitions, see the
         ``trans`` method.
         """
-        if isinstance(state, six.string_types):
+        if isinstance(state, str):
             state = self.get_state_by_name(state)
         if state not in self.states:
             raise StateNotInWorkflowError(state)
@@ -194,7 +188,7 @@ class Workflow(object):
 
     def set_initial_state(self, state):
         """Sets the initial state, used by the :meth:`.reset` method."""
-        if isinstance(state, six.string_types):
+        if isinstance(state, str):
             state = self.get_state_by_name(state)
         if not isinstance(state, State):
             raise InvalidStateObjectError(state)
@@ -206,7 +200,7 @@ class Workflow(object):
         """Reset the work flow to the initial state using the given object."""
         self._workflow_obj = wf_obj
         if init_state is not None:
-            if isinstance(init_state, six.string_types):
+            if isinstance(init_state, str):
                 init_state = self.get_state_by_name(init_state)
             if init_state not in self.states:
                 raise StateNotInWorkflowError()
@@ -223,19 +217,20 @@ class Workflow(object):
         returned by ``get_to_states`` is used.
         """
         if self._current_state is None:
-            raise ValueError('No current state set')
-        if isinstance(to_state, six.string_types):
+            raise ValueError("No current state set")
+        if isinstance(to_state, str):
             to_state = self.get_state_by_name(to_state)
         if to_state is None:
             to_state = self.get_to_states()
             if not to_state:
-                raise TransitionError('No state to transition to')
+                raise TransitionError("No state to transition to")
             to_state = to_state[0]
         if to_state not in self.states:
             raise StateNotInWorkflowError(to_state)
         if (self._current_state, to_state) not in self.edges:
-            raise TransitionError('No edge between edges %s and %s' % (
-                                  self._current_state, to_state))
+            raise TransitionError(
+                f"No edge between edges {self._current_state} and {to_state}"
+            )
         self._current_state.leave(self._workflow_obj)
         self._current_state = to_state
         self._current_state.enter(self._workflow_obj)
