@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2005-2011 Zuza Software Foundation
 #
@@ -26,21 +24,61 @@ The official recommendation is to use the extention .xlf for XLIFF files.
 from lxml import etree
 
 from translate.misc.multistring import multistring
+from translate.misc.xml_helpers import getXMLspace, setXMLlang, setXMLspace
 from translate.storage import base, lisa
-from translate.storage.lisa import getXMLspace
 from translate.storage.placeables.lisa import strelem_to_xml, xml_to_strelem
 from translate.storage.workflow import StateEnum as state
 
 
 # TODO: handle translation types
 
-ID_SEPARATOR = u"\04"
+ID_SEPARATOR = "\04"
 # ID_SEPARATOR is commonly used through toolkit to generate compound
 # unit ids (for instance to concatenate msgctxt and msgid in po), but
 # \04 is an illegal char in XML 1.0, ID_SEPARATOR_SAFE will be used
 # instead when converting between xliff and other toolkit supported
 # formats
-ID_SEPARATOR_SAFE = u"__%04__"
+ID_SEPARATOR_SAFE = "__%04__"
+
+
+# List of ASCII control codes which are unaccepted in XML.
+ASCII_CONTROL_CODES = [
+    "0000",  # Unicode Character 'NULL' (U+0000)
+    "0001",  # Unicode Character 'START OF HEADING' (U+0001)
+    "0002",  # Unicode Character 'START OF TEXT' (U+0002)
+    "0003",  # Unicode Character 'END OF TEXT' (U+0003)
+    "0004",  # Unicode Character 'END OF TRANSMISSION' (U+0004)
+    "0005",  # Unicode Character 'ENQUIRY' (U+0005)
+    "0006",  # Unicode Character 'ACKNOWLEDGE' (U+0006)
+    "0007",  # Unicode Character 'BELL' (U+0007), "\a" in Python
+    "0008",  # Unicode Character 'BACKSPACE' (U+0008), "\b" in Python
+    "000b",  # Unicode Character 'LINE TABULATION' (U+000B), "\v" in Python
+    "000c",  # Unicode Character 'FORM FEED (FF)' (U+000C), "\f" in Python
+    "000e",  # Unicode Character 'SHIFT OUT' (U+000E)
+    "000f",  # Unicode Character 'SHIFT IN' (U+000F)
+    "0010",  # Unicode Character 'DATA LINK ESCAPE' (U+0010)
+    "0011",  # Unicode Character 'DEVICE CONTROL ONE' (U+0011)
+    "0012",  # Unicode Character 'DEVICE CONTROL TWO' (U+0012)
+    "0013",  # Unicode Character 'DEVICE CONTROL THREE' (U+0013)
+    "0014",  # Unicode Character 'DEVICE CONTROL FOUR' (U+0014)
+    "0015",  # Unicode Character 'NEGATIVE ACKNOWLEDGE' (U+0015)
+    "0016",  # Unicode Character 'SYNCHRONOUS IDLE' (U+0016)
+    "0017",  # Unicode Character 'END OF TRANSMISSION BLOCK' (U+0017)
+    "0018",  # Unicode Character 'CANCEL' (U+0018)
+    "0019",  # Unicode Character 'END OF MEDIUM' (U+0019)
+    "001a",  # Unicode Character 'SUBSTITUTE' (U+001A)
+    "001b",  # Unicode Character 'ESCAPE' (U+001B)
+    "001c",  # Unicode Character 'INFORMATION SEPARATOR FOUR' (U+001C)
+    "001d",  # Unicode Character 'INFORMATION SEPARATOR THREE' (U+001D)
+    "001e",  # Unicode Character 'INFORMATION SEPARATOR TWO' (U+001E)
+    "001f",  # Unicode Character 'INFORMATION SEPARATOR ONE' (U+001F)
+]
+
+ASCII_CONTROL_CHARACTERS = {code: chr(int(code, 16)) for code in ASCII_CONTROL_CODES}
+
+ASCII_CONTROL_CHARACTERS_ESCAPES = {
+    code: "&#x%s;" % code.lstrip("0") or "0" for code in ASCII_CONTROL_CODES
+}
 
 
 class xliffunit(lisa.LISAunit):
@@ -49,7 +87,7 @@ class xliffunit(lisa.LISAunit):
     rootNode = "trans-unit"
     languageNode = "source"
     textNode = ""
-    namespace = 'urn:oasis:names:tc:xliff:document:1.1'
+    namespace = "urn:oasis:names:tc:xliff:document:1.1"
 
     _default_xml_space = "default"
 
@@ -62,19 +100,19 @@ class xliffunit(lisa.LISAunit):
     S_SIGNED_OFF = state.FINAL
 
     statemap = {
-                "new": S_UNTRANSLATED + 1,
-                "needs-translation": S_NEEDS_TRANSLATION,
-                "needs-adaptation": S_NEEDS_TRANSLATION + 1,
-                "needs-l10n": S_NEEDS_TRANSLATION + 2,
-                "needs-review-translation": S_NEEDS_REVIEW,
-                "needs-review-adaptation": S_NEEDS_REVIEW + 1,
-                "needs-review-l10n": S_NEEDS_REVIEW + 2,
-                "translated": S_TRANSLATED,
-                "signed-off": S_SIGNED_OFF,
-                "final": S_SIGNED_OFF + 1,
-                }
+        "new": S_UNTRANSLATED + 1,
+        "needs-translation": S_NEEDS_TRANSLATION,
+        "needs-adaptation": S_NEEDS_TRANSLATION + 1,
+        "needs-l10n": S_NEEDS_TRANSLATION + 2,
+        "needs-review-translation": S_NEEDS_REVIEW,
+        "needs-review-adaptation": S_NEEDS_REVIEW + 1,
+        "needs-review-l10n": S_NEEDS_REVIEW + 2,
+        "translated": S_TRANSLATED,
+        "signed-off": S_SIGNED_OFF,
+        "final": S_SIGNED_OFF + 1,
+    }
 
-    statemap_r = dict((i[1], i[0]) for i in statemap.iteritems())
+    statemap_r = {i[1]: i[0] for i in statemap.items()}
 
     STATE = {
         S_UNTRANSLATED: (state.EMPTY, state.NEEDS_WORK),
@@ -86,10 +124,19 @@ class xliffunit(lisa.LISAunit):
 
     def __init__(self, source, empty=False, **kwargs):
         """Override the constructor to set xml:space="preserve"."""
-        super(xliffunit, self).__init__(source, empty, **kwargs)
+        super().__init__(source, empty, **kwargs)
         if empty:
             return
-        lisa.setXMLspace(self.xmlelement, "preserve")
+        setXMLspace(self.xmlelement, "preserve")
+
+    def getNodeText(self, languageNode, xml_space="preserve"):
+        """Retrieves the term from the given :attr:`languageNode`."""
+        text = super().getNodeText(languageNode, xml_space=xml_space)
+        if text is not None:
+            # Unescape the unaccepted ASCII control characters.
+            for code, character in ASCII_CONTROL_CHARACTERS.items():
+                text = text.replace(ASCII_CONTROL_CHARACTERS_ESCAPES[code], character)
+        return text
 
     def createlanguageNode(self, lang, text, purpose):
         """Returns an xml Element setup with given parameters."""
@@ -101,7 +148,11 @@ class xliffunit(lisa.LISAunit):
         assert purpose
         langset = etree.Element(self.namespaced(purpose))
         # TODO: check language
-        #lisa.setXMLlang(langset, lang)
+        # setXMLlang(langset, lang)
+
+        # Escape the unaccepted ASCII control characters.
+        for code in ASCII_CONTROL_CODES:
+            text = text.replace(chr(int(code, 16)), "&#x%s;" % code.lstrip("0") or "0")
 
         langset.text = text
         return langset
@@ -112,20 +163,22 @@ class xliffunit(lisa.LISAunit):
         target = None
         nodes = []
         try:
-            source = self.xmlelement.iterchildren(self.namespaced(self.languageNode)).next()
-            target = self.xmlelement.iterchildren(self.namespaced('target')).next()
+            source = next(
+                self.xmlelement.iterchildren(self.namespaced(self.languageNode))
+            )
+            target = next(self.xmlelement.iterchildren(self.namespaced("target")))
             nodes = [source, target]
         except StopIteration:
             if source is not None:
                 nodes.append(source)
-            if not target is None:
+            if target is not None:
                 nodes.append(target)
         return nodes
 
-    def set_rich_source(self, value, sourcelang='en'):
+    def set_rich_source(self, value, sourcelang="en"):
         sourcelanguageNode = self.get_source_dom()
         if sourcelanguageNode is None:
-            sourcelanguageNode = self.createlanguageNode(sourcelang, u'', "source")
+            sourcelanguageNode = self.createlanguageNode(sourcelang, "", "source")
             self.set_source_dom(sourcelanguageNode)
 
         # Clear sourcelanguageNode first
@@ -135,27 +188,31 @@ class xliffunit(lisa.LISAunit):
 
         strelem_to_xml(sourcelanguageNode, value[0])
 
-    def get_rich_source(self):
-        #rsrc = xml_to_strelem(self.source_dom)
-        #logging.debug('rich source: %s' % (repr(rsrc)))
-        #from dubulib.debug.misc import print_stack_funcs
-        #print_stack_funcs()
+    @property
+    def rich_source(self):
+        # rsrc = xml_to_strelem(self.source_dom)
+        # logging.debug('rich source: %s' % (repr(rsrc)))
+        # from dubulib.debug.misc import print_stack_funcs
+        # print_stack_funcs()
         return [
-            xml_to_strelem(self.source_dom,
-                           getXMLspace(self.xmlelement,
-                                       self._default_xml_space))
+            xml_to_strelem(
+                self.source_dom, getXMLspace(self.xmlelement, self._default_xml_space)
+            )
         ]
-    rich_source = property(get_rich_source, set_rich_source)
 
-    def set_rich_target(self, value, lang='xx', append=False):
+    @rich_source.setter
+    def rich_source(self, value):
+        self.set_rich_source(value)
+
+    def set_rich_target(self, value, lang="xx", append=False):
         self._rich_target = None
         if value is None:
-            self.set_target_dom(self.createlanguageNode(lang, u'', "target"))
+            self.set_target_dom(self.createlanguageNode(lang, "", "target"))
             return
 
         languageNode = self.get_target_dom()
         if languageNode is None:
-            languageNode = self.createlanguageNode(lang, u'', "target")
+            languageNode = self.createlanguageNode(lang, "", "target")
             self.set_target_dom(languageNode, append)
 
         # Clear languageNode first
@@ -168,17 +225,28 @@ class xliffunit(lisa.LISAunit):
 
     def get_rich_target(self, lang=None):
         """retrieves the "target" text (second entry), or the entry in the
-        specified language, if it exists"""
+        specified language, if it exists
+        """
         if self._rich_target is None:
             self._rich_target = [
-                xml_to_strelem(self.get_target_dom(lang),
-                getXMLspace(self.xmlelement, self._default_xml_space))
+                xml_to_strelem(
+                    self.get_target_dom(lang),
+                    getXMLspace(self.xmlelement, self._default_xml_space),
+                )
             ]
         return self._rich_target
-    rich_target = property(get_rich_target, set_rich_target)
 
-    def addalttrans(self, txt, origin=None, lang=None, sourcetxt=None,
-                    matchquality=None):
+    @property
+    def rich_target(self):
+        return self.get_rich_target()
+
+    @rich_target.setter
+    def rich_target(self, value):
+        self.set_rich_target(value)
+
+    def addalttrans(
+        self, txt, origin=None, lang=None, sourcetxt=None, matchquality=None
+    ):
         """Adds an alt-trans tag and alt-trans components to the unit.
 
         :type txt: String
@@ -187,13 +255,9 @@ class xliffunit(lisa.LISAunit):
 
         # TODO: support adding a source tag ad match quality attribute.  At the
         # source tag is needed to inject fuzzy matches from a TM.
-        if isinstance(txt, str):
-            txt = txt.decode("utf-8")
         alttrans = etree.SubElement(self.xmlelement, self.namespaced("alt-trans"))
-        lisa.setXMLspace(alttrans, "preserve")
+        setXMLspace(alttrans, "preserve")
         if sourcetxt:
-            if isinstance(sourcetxt, str):
-                sourcetxt = sourcetxt.decode("utf-8")
             altsource = etree.SubElement(alttrans, self.namespaced("source"))
             altsource.text = sourcetxt
         alttarget = etree.SubElement(alttrans, self.namespaced("target"))
@@ -203,11 +267,12 @@ class xliffunit(lisa.LISAunit):
         if origin:
             alttrans.set("origin", origin)
         if lang:
-            lisa.setXMLlang(alttrans, lang)
+            setXMLlang(alttrans, lang)
 
     def getalttrans(self, origin=None):
         """Returns <alt-trans> for the given origin as a list of units. No
-        origin means all alternatives."""
+        origin means all alternatives.
+        """
         translist = []
         for node in self.xmlelement.iterdescendants(self.namespaced("alt-trans")):
             if self.correctorigin(node, origin):
@@ -218,15 +283,17 @@ class xliffunit(lisa.LISAunit):
                 # the source tag is optional
                 sourcenode = node.iterdescendants(self.namespaced("source"))
                 try:
-                    newunit.source = lisa.getText(sourcenode.next(),
-                                                  getXMLspace(node, self._default_xml_space))
+                    newunit.source = lisa.getText(
+                        next(sourcenode), getXMLspace(node, self._default_xml_space)
+                    )
                 except StopIteration:
                     pass
 
                 # must have one or more targets
                 targetnode = node.iterdescendants(self.namespaced("target"))
-                newunit.target = lisa.getText(targetnode.next(),
-                                              getXMLspace(node, self._default_xml_space))
+                newunit.target = lisa.getText(
+                    next(targetnode), getXMLspace(node, self._default_xml_space)
+                )
                 # TODO: support multiple targets better
                 # TODO: support notes in alt-trans
                 newunit.xmlelement = node
@@ -247,8 +314,6 @@ class xliffunit(lisa.LISAunit):
             text = text.strip()
         if not text:
             return
-        if isinstance(text, str):
-            text = text.decode("utf-8")
         note = etree.SubElement(self.xmlelement, self.namespaced("note"))
         note.text = text
         if origin:
@@ -266,18 +331,24 @@ class xliffunit(lisa.LISAunit):
         # TODO: consider using xpath to construct initial_list directly
         # or to simply get the correct text from the outset (just remember to
         # check for duplication.
-        initial_list = [lisa.getText(note, getXMLspace(self.xmlelement, self._default_xml_space)) for note in note_nodes if self.correctorigin(note, origin)]
+        initial_list = [
+            lisa.getText(note, getXMLspace(self.xmlelement, self._default_xml_space))
+            for note in note_nodes
+            if self.correctorigin(note, origin)
+        ]
 
         # Remove duplicate entries from list:
         dictset = {}
-        note_list = [dictset.setdefault(note, note) for note in initial_list if note not in dictset]
-
-        return note_list
+        return [
+            dictset.setdefault(note, note)
+            for note in initial_list
+            if note not in dictset
+        ]
 
     def getnotes(self, origin=None):
-        return '\n'.join(self._getnotelist(origin=origin))
+        return "\n".join(self._getnotelist(origin=origin))
 
-    def removenotes(self, origin="translator"):
+    def removenotes(self, origin=None):
         """Remove all the translator notes."""
         notes = self.xmlelement.iterdescendants(self.namespaced("note"))
         for note in notes:
@@ -289,7 +360,7 @@ class xliffunit(lisa.LISAunit):
         # TODO: consider factoring out: some duplication between XLIFF and TMX
         text = errorname
         if errortext:
-            text += ': ' + errortext
+            text += ": " + errortext
         self.addnote(text, origin="pofilter")
 
     def geterrors(self):
@@ -298,7 +369,7 @@ class xliffunit(lisa.LISAunit):
         notelist = self._getnotelist(origin="pofilter")
         errordict = {}
         for note in notelist:
-            errorname, errortext = note.split(': ')
+            errorname, errortext = note.split(": ")
             errordict[errorname] = errortext
         return errordict
 
@@ -359,7 +430,8 @@ class xliffunit(lisa.LISAunit):
     def markreviewneeded(self, needsreview=True, explanation=None):
         """Marks the unit to indicate whether it needs review.
 
-        Adds an optional explanation as a note."""
+        Adds an optional explanation as a note.
+        """
         state_id = self.get_state_id()
         if needsreview and state_id != self.S_NEEDS_REVIEW:
             self.set_state_n(self.S_NEEDS_REVIEW)
@@ -386,22 +458,24 @@ class xliffunit(lisa.LISAunit):
             if state_id < self.S_UNREVIEWED:
                 self.set_state_n(self.S_UNREVIEWED)
 
-    def settarget(self, text, lang='xx', append=False):
+    def settarget(self, target, lang="xx", append=False):
         """Sets the target string to the given value."""
-        super(xliffunit, self).settarget(text, lang, append)
-        if text:
+        super().settarget(target, lang, append)
+        if target:
+            if getXMLspace(self.xmlelement) != "preserve":
+                setXMLspace(self.xmlelement, "preserve")
             self.marktranslated()
 
-# This code is commented while this will almost always return false.
-# This way pocount, etc. works well.
-#    def istranslated(self):
-#        targetnode = self.getlanguageNode(lang=None, index=1)
-#        return not targetnode is None and \
-#                (targetnode.get("state") == "translated")
+    # This code is commented while this will almost always return false.
+    # This way pocount, etc. works well.
+    #    def istranslated(self):
+    #        targetnode = self.getlanguageNode(lang=None, index=1)
+    #        return not targetnode is None and \
+    #                (targetnode.get("state") == "translated")
 
     def istranslatable(self):
         value = self.xmlelement.get("translate")
-        if value and value.lower() == 'no':
+        if value and value.lower() == "no":
             return False
         return True
 
@@ -415,23 +489,27 @@ class xliffunit(lisa.LISAunit):
         self.xmlelement.set("id", id.replace(ID_SEPARATOR, ID_SEPARATOR_SAFE))
 
     def getid(self):
-        uid = u""
+        uid = ""
         try:
-            filename = self.xmlelement.iterancestors(self.namespaced('file')).next().get('original')
+            filename = next(self.xmlelement.iterancestors(self.namespaced("file"))).get(
+                "original"
+            )
             if filename:
                 uid = filename + ID_SEPARATOR
         except StopIteration:
             # unit has no proper file ancestor, probably newly created
             pass
         # hide the fact that we sanitize ID_SEPERATOR
-        uid += unicode(self.xmlelement.get("id") or u"").replace(ID_SEPARATOR_SAFE, ID_SEPARATOR)
+        uid += str(self.xmlelement.get("id") or "").replace(
+            ID_SEPARATOR_SAFE, ID_SEPARATOR
+        )
         return uid
 
     def addlocation(self, location):
         self.setid(location)
 
     def getlocations(self):
-        id_attr = unicode(self.xmlelement.get("id") or u"")
+        id_attr = str(self.xmlelement.get("id") or "")
         # XLIFF files downloaded from PO projects in Pootle
         # might have id equal to .source, so let's avoid
         # that:
@@ -441,7 +519,8 @@ class xliffunit(lisa.LISAunit):
 
     def createcontextgroup(self, name, contexts=None, purpose=None):
         """Add the context group to the trans-unit with contexts a list with
-        (type, text) tuples describing each context."""
+        (type, text) tuples describing each context.
+        """
         assert contexts
         group = etree.Element(self.namespaced("context-group"))
         # context-group tags must appear at the start within <group>
@@ -455,8 +534,6 @@ class xliffunit(lisa.LISAunit):
         if purpose:
             group.set("purpose", purpose)
         for type, text in contexts:
-            if isinstance(text, str):
-                text = text.decode("utf-8")
             context = etree.SubElement(group, self.namespaced("context"))
             context.text = text
             context.set("context-type", type)
@@ -471,7 +548,15 @@ class xliffunit(lisa.LISAunit):
                 contexts = group.iterdescendants(self.namespaced("context"))
                 pairs = []
                 for context in contexts:
-                    pairs.append((context.get("context-type"), lisa.getText(context, getXMLspace(self.xmlelement, self._default_xml_space))))
+                    pairs.append(
+                        (
+                            context.get("context-type"),
+                            lisa.getText(
+                                context,
+                                getXMLspace(self.xmlelement, self._default_xml_space),
+                            ),
+                        )
+                    )
                 groups.append(pairs)  # not extend
         return groups
 
@@ -481,7 +566,7 @@ class xliffunit(lisa.LISAunit):
 
     def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
         # TODO: consider other attributes like "approved"
-        super(xliffunit, self).merge(otherunit, overwrite, comments)
+        super().merge(otherunit, overwrite, comments)
         if self.target:
             self.marktranslated()
             if otherunit.isfuzzy():
@@ -507,11 +592,12 @@ class xliffunit(lisa.LISAunit):
     @classmethod
     def multistring_to_rich(cls, mstr):
         """Override :meth:`TranslationUnit.multistring_to_rich` which is used
-        by the ``rich_source`` and ``rich_target`` properties."""
+        by the ``rich_source`` and ``rich_target`` properties.
+        """
         strings = mstr
         if isinstance(mstr, multistring):
             strings = mstr.strings
-        elif isinstance(mstr, basestring):
+        elif isinstance(mstr, str):
             strings = [mstr]
 
         return [xml_to_strelem(s) for s in strings]
@@ -519,35 +605,37 @@ class xliffunit(lisa.LISAunit):
     @classmethod
     def rich_to_multistring(cls, elem_list):
         """Override :meth:`TranslationUnit.rich_to_multistring` which is used
-        by the ``rich_source`` and ``rich_target`` properties."""
-        return multistring([unicode(elem) for elem in elem_list])
+        by the ``rich_source`` and ``rich_target`` properties.
+        """
+        return multistring([str(elem) for elem in elem_list])
 
 
 class xlifffile(lisa.LISAfile):
     """Class representing a XLIFF file store."""
+
     UnitClass = xliffunit
     Name = "XLIFF Translation File"
     Mimetypes = ["application/x-xliff", "application/x-xliff+xml"]
     Extensions = ["xlf", "xliff", "sdlxliff"]
     rootNode = "xliff"
     bodyNode = "body"
-    XMLskeleton = '''<?xml version="1.0" ?>
+    XMLskeleton = """<?xml version="1.0" ?>
 <xliff version='1.1' xmlns='urn:oasis:names:tc:xliff:document:1.1'>
 <file original='NoName' source-language='en' datatype='plaintext'>
 <body>
 </body>
 </file>
-</xliff>'''
-    namespace = 'urn:oasis:names:tc:xliff:document:1.1'
-    unversioned_namespace = 'urn:oasis:names:tc:xliff:document:'
+</xliff>"""
+    XMLindent = {"indent": "  ", "max_level": 4, "toplevel": False}
+    namespace = "urn:oasis:names:tc:xliff:document:1.1"
+    unversioned_namespace = "urn:oasis:names:tc:xliff:document:"
 
     suggestions_in_format = True
     """xliff units have alttrans tags which can be used to store suggestions"""
 
     def __init__(self, *args, **kwargs):
         self._filename = None
-        lisa.LISAfile.__init__(self, *args, **kwargs)
-        self._messagenum = 0
+        super().__init__(*args, **kwargs)
 
     def initbody(self):
         # detect the xliff namespace, handle both 1.1 and 1.2
@@ -563,17 +651,21 @@ class xlifffile(lisa.LISAfile):
         if self._filename:
             filenode = self.getfilenode(self._filename, createifmissing=True)
         else:
-            filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+            filenode = next(
+                self.document.getroot().iterchildren(self.namespaced("file"))
+            )
         self.body = self.getbodynode(filenode, createifmissing=True)
 
     def addheader(self):
         """Initialise the file header."""
         pass
 
-    def createfilenode(self, filename, sourcelanguage=None,
-                       targetlanguage=None, datatype='plaintext'):
-        """creates a filenode with the given filename. All parameters
-        are needed for XLIFF compliance."""
+    def createfilenode(
+        self, filename, sourcelanguage=None, targetlanguage=None, datatype="plaintext"
+    ):
+        """creates a filenode with the given filename. All parameters are
+        needed for XLIFF compliance.
+        """
         if sourcelanguage is None:
             sourcelanguage = self.sourcelanguage
         if targetlanguage is None:
@@ -594,7 +686,7 @@ class xlifffile(lisa.LISAfile):
         if targetlanguage:
             filenode.set("target-language", targetlanguage)
         filenode.set("datatype", datatype)
-        bodyNode = etree.SubElement(filenode, self.namespaced(self.bodyNode))
+        etree.SubElement(filenode, self.namespaced(self.bodyNode))
         return filenode
 
     def getfilename(self, filenode):
@@ -609,8 +701,8 @@ class xlifffile(lisa.LISAfile):
         """returns all filenames in this XLIFF file"""
         filenodes = self.document.getroot().iterchildren(self.namespaced("file"))
         filenames = [self.getfilename(filenode) for filenode in filenodes]
-        filenames = filter(None, filenames)
-        if len(filenames) == 1 and filenames[0] == '':
+        filenames = list(filter(None, filenames))
+        if len(filenames) == 1 and filenames[0] == "":
             filenames = []
         return filenames
 
@@ -621,49 +713,51 @@ class xlifffile(lisa.LISAfile):
             if self.getfilename(filenode) == filename:
                 return filenode
         if createifmissing:
-            filenode = self.createfilenode(filename)
-            return filenode
+            return self.createfilenode(filename)
         return None
 
     def getids(self, filename=None):
         if not filename:
-            return super(xlifffile, self).getids()
+            return super().getids()
 
         self.id_index = {}
         prefix = filename + ID_SEPARATOR
         units = (unit for unit in self.units if unit.getid().startswith(prefix))
         for index, unit in enumerate(units):
-            self.id_index[unit.getid()[len(prefix):]] = unit
+            self.id_index[unit.getid()[len(prefix) :]] = unit
         return self.id_index.keys()
 
     def setsourcelanguage(self, language):
         if not language:
             return
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
-        filenode.set("source-language", language)
+        for filenode in self.document.getroot().iterchildren(self.namespaced("file")):
+            filenode.set("source-language", language)
 
     def getsourcelanguage(self):
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode = next(self.document.getroot().iterchildren(self.namespaced("file")))
         return filenode.get("source-language")
+
     sourcelanguage = property(getsourcelanguage, setsourcelanguage)
 
     def settargetlanguage(self, language):
         if not language:
             return
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
-        filenode.set("target-language", language)
+        for filenode in self.document.getroot().iterchildren(self.namespaced("file")):
+            filenode.set("target-language", language)
 
     def gettargetlanguage(self):
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode = next(self.document.getroot().iterchildren(self.namespaced("file")))
         return filenode.get("target-language")
+
     targetlanguage = property(gettargetlanguage, settargetlanguage)
 
     def getdatatype(self, filename=None):
         """Returns the datatype of the stored file. If no filename is given,
-        the datatype of the first file is given."""
+        the datatype of the first file is given.
+        """
         if filename:
             node = self.getfilenode(filename)
-            if not node is None:
+            if node is not None:
                 return node.get("datatype")
         else:
             filenames = self.getfilenames()
@@ -682,7 +776,7 @@ class xlifffile(lisa.LISAfile):
         """
         if filename:
             node = self.getfilenode(filename)
-            if not node is None:
+            if node is not None:
                 return node.get("date")
         else:
             filenames = self.getfilenames()
@@ -692,12 +786,14 @@ class xlifffile(lisa.LISAfile):
 
     def removedefaultfile(self):
         """We want to remove the default file-tag as soon as possible if we
-        know if still present and empty."""
+        know if still present and empty.
+        """
         filenodes = list(self.document.getroot().iterchildren(self.namespaced("file")))
         if len(filenodes) > 1:
             for filenode in filenodes:
-                if (filenode.get("original") == "NoName" and
-                    not list(filenode.iterdescendants(self.namespaced(self.UnitClass.rootNode)))):
+                if filenode.get("original") == "NoName" and not list(
+                    filenode.iterdescendants(self.namespaced(self.UnitClass.rootNode))
+                ):
                     self.document.getroot().remove(filenode)
                 break
 
@@ -706,7 +802,7 @@ class xlifffile(lisa.LISAfile):
         # TODO: Deprecated?
         headernode = filenode.iterchildren(self.namespaced("header"))
         try:
-            return headernode.next()
+            return next(headernode)
         except StopIteration:
             pass
         if not createifmissing:
@@ -718,24 +814,34 @@ class xlifffile(lisa.LISAfile):
         """finds the body node for the given filenode"""
         bodynode = filenode.iterchildren(self.namespaced("body"))
         try:
-            return bodynode.next()
+            return next(bodynode)
         except StopIteration:
             pass
         if not createifmissing:
             return None
-        bodynode = etree.SubElement(filenode, self.namespaced("body"))
-        return bodynode
+        return etree.SubElement(filenode, self.namespaced("body"))
+
+    def addunit(self, unit, new=True):
+        parts = unit.getid().split("\x04")
+        if len(parts) > 1:
+            filename, unitid = parts[0], "\x04".join(parts[1:])
+            self.switchfile(filename, createifmissing=True)
+            unit.setid(unitid)
+        super().addunit(unit, new=new)
 
     def addsourceunit(self, source, filename="NoName", createifmissing=False):
-        """adds the given trans-unit to the last used body node if the
-        filename has changed it uses the slow method instead (will
-        create the nodes required if asked). Returns success"""
-        if self._filename != filename:
-            if not self.switchfile(filename, createifmissing):
-                return None
-        unit = super(xlifffile, self).addsourceunit(source)
-        self._messagenum += 1
-        unit.setid("%d" % self._messagenum)
+        """adds the given trans-unit to the last used body node if the filename
+        has changed it uses the slow method instead (will create the nodes
+        required if asked). Returns success
+        """
+        if not self.switchfile(filename, createifmissing):
+            return None
+        unit = super().addsourceunit(source)
+        # Add unique ID based on number of units. Doing this inside a body/file
+        # tag would be better, but performs way worse as we have to query the
+        # XML tree for that.
+        messagenum = len(self.units) + 1
+        unit.setid(f"{messagenum}")
         return unit
 
     def switchfile(self, filename, createifmissing=False):
@@ -744,6 +850,8 @@ class xlifffile(lisa.LISAfile):
         :returns: Success
         :rtype: Boolean
         """
+        if self._filename == filename:
+            return True
         self._filename = filename
         filenode = self.getfilenode(filename)
         if filenode is None:
@@ -753,39 +861,32 @@ class xlifffile(lisa.LISAfile):
             self.document.getroot().append(filenode)
 
         self.body = self.getbodynode(filenode, createifmissing=createifmissing)
-        if self.body is None:
-            return False
-        self._messagenum = len(list(self.body.iterdescendants(self.namespaced("trans-unit"))))
-        # TODO: was 0 based before - consider
-    #    messagenum = len(self.units)
-        # TODO: we want to number them consecutively inside a body/file tag
-        # instead of globally in the whole XLIFF file, but using
-        # len(self.units) will be much faster
-        return True
+        return self.body is not None
 
     def creategroup(self, filename="NoName", createifmissing=False, restype=None):
         """adds a group tag into the specified file"""
-        if self._filename != filename:
-            if not self.switchfile(filename, createifmissing):
-                return None
+        if not self.switchfile(filename, createifmissing):
+            return None
         group = etree.SubElement(self.body, self.namespaced("group"))
         if restype:
             group.set("restype", restype)
         return group
 
-    def __str__(self):
+    def serialize(self, out):
         self.removedefaultfile()
-        return super(xlifffile, self).__str__()
+        super().serialize(out)
 
     @classmethod
     def parsestring(cls, storestring):
         """Parses the string to return the correct file object"""
-        xliff = super(xlifffile, cls).parsestring(storestring)
+        xliff = super().parsestring(storestring)
         if xliff.units:
             header = xliff.units[0]
-            if (("gettext-domain-header" in (header.getrestype() or "") or
-                 xliff.getdatatype() == "po") and
-                 cls.__name__.lower() != "poxlifffile"):
+            if (
+                "gettext-domain-header" in (header.getrestype() or "")
+                or xliff.getdatatype() == "po"
+            ) and cls.__name__.lower() != "poxlifffile":
                 from translate.storage import poxliff
+
                 xliff = poxliff.PoXliffFile.parsestring(storestring)
         return xliff
