@@ -19,24 +19,41 @@
 r"""Class that manages YAML data files for translation
 """
 
-
 import uuid
 
 from ruamel.yaml import YAML, YAMLError
-from ruamel.yaml.comments import CommentedMap
+from ruamel.yaml.comments import CommentedMap, TaggedScalar
 
 from translate.lang.data import cldr_plural_categories, plural_tags
 from translate.misc.multistring import multistring
 from translate.storage import base
 
 
-class YAMLUnit(base.TranslationUnit):
+class YAMLUnitId(base.UnitId):
+    KEY_SEPARATOR = "->"
+    INDEX_SEPARATOR = "->"
+
+    def __str__(self):
+        result = super().__str__()
+        # Strip leading ->
+        if result.startswith(self.KEY_SEPARATOR):
+            return result[len(self.KEY_SEPARATOR) :]
+        return result
+
+
+class YAMLUnit(base.DictUnit):
     """A YAML entry"""
 
+    IdClass = YAMLUnitId
+    DefaultDict = dict
+
     def __init__(self, source=None, **kwargs):
-        self._id = None
+        # Ensure we have ID (for serialization)
         if source:
             self.source = source
+            self._id = hex(hash(source))
+        else:
+            self._id = str(uuid.uuid4())
         super().__init__(source)
 
     @property
@@ -49,18 +66,22 @@ class YAMLUnit(base.TranslationUnit):
 
     def setid(self, value):
         self._id = value
+        self._unitid = None
 
     def getid(self):
-        # Ensure we have ID (for serialization)
-        if self._id is None:
-            self._id = str(uuid.uuid4())
         return self._id
 
     def getlocations(self):
         return [self.getid()]
 
+    def convert_target(self):
+        return self.target
 
-class YAMLFile(base.TranslationStore):
+    def storevalues(self, output):
+        self.storevalue(output, self.convert_target())
+
+
+class YAMLFile(base.DictStore):
     """A YAML file"""
 
     UnitClass = YAMLUnit
@@ -68,11 +89,11 @@ class YAMLFile(base.TranslationStore):
     def __init__(self, inputfile=None, **kwargs):
         """construct a YAML file, optionally reading in from inputfile."""
         super().__init__(**kwargs)
-        self.filename = ''
+        self.filename = ""
         self._original = self.get_root_node()
         self.dump_args = {
-            'default_flow_style': False,
-            'preserve_quotes': True,
+            "default_flow_style": False,
+            "preserve_quotes": True,
         }
         if inputfile is not None:
             self.parse(inputfile)
@@ -81,9 +102,6 @@ class YAMLFile(base.TranslationStore):
         """Returns root node for serialize"""
         return CommentedMap()
 
-    def serialize_value(self, value):
-        return value
-
     @property
     def yaml(self):
         yaml = YAML()
@@ -92,36 +110,12 @@ class YAMLFile(base.TranslationStore):
         return yaml
 
     def serialize(self, out):
-        def nested_set(target, path, value):
-            value = self.serialize_value(value)
-            if len(path) > 1:
-                if len(path) >= 2 and path[1] and path[1][0] == '[' and path[1][-1] == ']' and path[1][1:-1].isdigit():
-                    if path[0] not in target:
-                        target[path[0]] = []
-                    if len(path) > 2:
-                        value = nested_set(CommentedMap(), path[2:], value)
-                    pos = int(path[1][1:-1])
-                    if len(target[path[0]]) < pos + 1:
-                        target[path[0]].append(value)
-                    else:
-                        target[path[0]][pos] = value
-                else:
-                    # Add empty dict in case there is value and we
-                    # expect dict
-                    if path[0] not in target or not isinstance(target[path[0]], dict):
-                        target[path[0]] = CommentedMap()
-                    nested_set(target[path[0]], path[1:], value)
-            else:
-                target[path[0]] = value
-            return target
-
         # Always start with valid root even if original file was empty
         if self._original is None:
             self._original = self.get_root_node()
 
         units = self.preprocess(self._original)
-        for unit in self.unit_iter():
-            nested_set(units, unit.getid().split('->'), unit.target)
+        self.serialize_units(units)
         self.yaml.dump(self._original, out)
 
     def _parse_dict(self, data, prev):
@@ -129,18 +123,17 @@ class YAMLFile(base.TranslationStore):
         for k, v in data.non_merged_items():
             if not isinstance(k, str):
                 raise base.ParseError(
-                    'Key not string: {0}/{1} ({2})'.format(prev, k, type(k))
+                    "Key not string: {}/{} ({})".format(prev, k, type(k))
                 )
 
-            for x in self._flatten(v, '->'.join((prev, k)) if prev else k):
-                yield x
+            yield from self._flatten(v, prev + [("key", k)])
 
-    def _flatten(self, data, prev=""):
-        """Flatten YAML dictionary.
-        """
+    def _flatten(self, data, prev=None):
+        """Flatten YAML dictionary."""
+        if prev is None:
+            prev = self.UnitClass.IdClass([])
         if isinstance(data, dict):
-            for x in self._parse_dict(data, prev):
-                yield x
+            yield from self._parse_dict(data, prev)
         else:
             if isinstance(data, str):
                 yield (prev, data)
@@ -148,16 +141,18 @@ class YAMLFile(base.TranslationStore):
                 yield (prev, str(data))
             elif isinstance(data, list):
                 for k, v in enumerate(data):
-                    key = '[{0}]'.format(k)
-                    for value in self._flatten(v, '->'.join((prev, key))):
-                        yield value
+                    yield from self._flatten(v, prev + [("index", k)])
+            elif isinstance(data, TaggedScalar):
+                yield (prev, data.value)
             elif data is None:
                 pass
             else:
-                raise ValueError("We don't handle these values:\n"
-                                 "Type: %s\n"
-                                 "Data: %s\n"
-                                 "Previous: %s" % (type(data), data, prev))
+                raise ValueError(
+                    "We don't handle these values:\n"
+                    "Type: %s\n"
+                    "Data: %s\n"
+                    "Previous: %s" % (type(data), data, prev)
+                )
 
     def preprocess(self, data):
         """Preprocess hook for child formats"""
@@ -165,35 +160,60 @@ class YAMLFile(base.TranslationStore):
 
     def parse(self, input):
         """parse the given file or file source string"""
-        if hasattr(input, 'name'):
+        if hasattr(input, "name"):
             self.filename = input.name
-        elif not getattr(self, 'filename', ''):
-            self.filename = ''
+        elif not getattr(self, "filename", ""):
+            self.filename = ""
         if hasattr(input, "read"):
             src = input.read()
             input.close()
             input = src
         if isinstance(input, bytes):
-            input = input.decode('utf-8')
+            input = input.decode("utf-8")
         try:
             self._original = self.yaml.load(input)
         except YAMLError as e:
-            message = e.problem if hasattr(e, 'problem') else e.message
-            if hasattr(e, 'problem_mark'):
-                message += ' {0}'.format(e.problem_mark)
+            message = e.problem if hasattr(e, "problem") else e.message
+            if hasattr(e, "problem_mark"):
+                message += f" {e.problem_mark}"
             raise base.ParseError(message)
 
         content = self.preprocess(self._original)
 
         for k, data in self._flatten(content):
             unit = self.UnitClass(data)
-            unit.setid(k)
+            unit.set_unitid(k)
             self.addunit(unit)
 
+    def removeunit(self, unit):
+        if self._original is not None:
+            units = self.preprocess(self._original)
+            unit.storevalue(units, None, unset=True)
+        super().removeunit(unit)
+
+
+class RubyYAMLUnit(YAMLUnit):
+    def convert_target(self):
+        if not isinstance(self.target, multistring):
+            return self.target
+
+        tags = plural_tags.get(self._store.targetlanguage, plural_tags["en"])
+
+        strings = [str(s) for s in self.target.strings]
+
+        # Sync plural_strings elements to plural_tags count.
+        if len(strings) < len(tags):
+            strings += [""] * (len(tags) - len(strings))
+        strings = strings[: len(tags)]
+
+        return CommentedMap(zip(tags, strings))
+
 
 class RubyYAMLFile(YAMLFile):
     """Ruby YAML file, it has language code as first node."""
 
+    UnitClass = RubyYAMLUnit
+
     def preprocess(self, data):
         if isinstance(data, CommentedMap) and len(data) == 1:
             lang = list(data.keys())[0]
@@ -203,35 +223,17 @@ class RubyYAMLFile(YAMLFile):
 
     def get_root_node(self):
         """Returns root node for serialize"""
-        if self.targetlanguage is not None:
-            result = CommentedMap()
-            result[self.targetlanguage] = CommentedMap()
-            return result
-        return CommentedMap()
+        result = CommentedMap()
+        result[self.targetlanguage or "en"] = CommentedMap()
+        return result
 
     def _parse_dict(self, data, prev):
         # Does this look like a plural?
-        if data and all((x in cldr_plural_categories for x in data.keys())):
+        if data and all(x in cldr_plural_categories for x in data.keys()):
             # Ensure we have correct plurals ordering.
             values = [data[item] for item in cldr_plural_categories if item in data]
             yield (prev, multistring(values))
             return
 
         # Handle normal dict
-        for x in super()._parse_dict(data, prev):
-            yield x
-
-    def serialize_value(self, value):
-        if not isinstance(value, multistring):
-            return value
-
-        tags = plural_tags.get(self.targetlanguage, plural_tags['en'])
-
-        strings = [str(s) for s in value.strings]
-
-        # Sync plural_strings elements to plural_tags count.
-        if len(strings) < len(tags):
-            strings += [''] * (len(tags) - len(strings))
-        strings = strings[:len(tags)]
-
-        return CommentedMap(zip(tags, strings))
+        yield from super()._parse_dict(data, prev)
