@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2005-2008,2010 Zuza Software Foundation
 #
@@ -25,7 +23,6 @@ for examples and usage instructions.
 """
 
 import os
-import six
 import sys
 
 from translate.misc import optrecurse
@@ -37,7 +34,9 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
 
     def parse_args(self, args=None, values=None):
         """parses the command line options, handling implicit input/output args"""
-        (options, args) = optrecurse.optparse.OptionParser.parse_args(self, args, values)
+        (options, args) = optrecurse.optparse.OptionParser.parse_args(
+            self, args, values
+        )
         # some intelligence as to what reasonable people might give on the command line
         if args and not options.input:
             if not options.output:
@@ -52,7 +51,9 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
         if not options.output:
             self.error("output file is required")
         if args:
-            self.error("You have used an invalid combination of --input, --output and freestanding args")
+            self.error(
+                "You have used an invalid combination of --input, --output and freestanding args"
+            )
         if isinstance(options.input, list) and len(options.input) == 1:
             options.input = options.input[0]
         return (options, args)
@@ -60,20 +61,29 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
     def set_usage(self, usage=None):
         """sets the usage string - if usage not given, uses getusagestring for each option"""
         if usage is None:
-            self.usage = "%prog " + " ".join([self.getusagestring(option) for option in self.option_list]) + \
-                "\n  input directory is searched for PO files, PO files with name of conflicting string are output in output directory"
+            self.usage = (
+                "%prog "
+                + " ".join([self.getusagestring(option) for option in self.option_list])
+                + "\n  input directory is searched for PO files, PO files with name of conflicting string are output in output directory"
+            )
         else:
-            super(ConflictOptionParser, self).set_usage(usage)
+            super().set_usage(usage)
 
     def recursiveprocess(self, options):
         """recurse through directories and process files"""
-        if self.isrecursive(options.input, 'input') and getattr(options, "allowrecursiveinput", True):
-            if not self.isrecursive(options.output, 'output'):
+        if self.isrecursive(options.input, "input") and getattr(
+            options, "allowrecursiveinput", True
+        ):
+            if not self.isrecursive(options.output, "output"):
+                self.warning("Output directory does not exist. Attempting to create")
                 try:
-                    self.warning("Output directory does not exist. Attempting to create")
                     os.mkdir(options.output)
-                except:
-                    self.error(optrecurse.optparse.OptionValueError("Output directory does not exist, attempt to create failed"))
+                except Exception:
+                    self.error(
+                        optrecurse.optparse.OptionValueError(
+                            "Output directory does not exist, attempt to create failed"
+                        )
+                    )
             if isinstance(options.input, list):
                 inputfiles = self.recurseinputfilelist(options)
             else:
@@ -91,7 +101,11 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
             try:
                 success = self.processfile(None, options, fullinputpath)
             except Exception:
-                self.warning("Error processing: input %s" % (fullinputpath), options, sys.exc_info())
+                self.warning(
+                    "Error processing: input %s" % (fullinputpath),
+                    options,
+                    sys.exc_info(),
+                )
                 success = False
             progress_bar.report_progress(inputpath, success)
         del progress_bar
@@ -137,24 +151,29 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
     def buildconflictmap(self):
         """work out which strings are conflicting"""
         self.conflictmap = {}
-        for source, translations in six.iteritems(self.textmap):
+        for source, translations in self.textmap.items():
             source = self.flatten(source, " ")
             if len(source) <= 1:
                 continue
             if len(translations) > 1:
-                uniquetranslations = dict.fromkeys([target for target, unit, filename in translations])
+                uniquetranslations = dict.fromkeys(
+                    [target for target, unit, filename in translations]
+                )
                 if len(uniquetranslations) > 1:
                     self.conflictmap[source] = translations
 
     def outputconflicts(self, options):
         """saves the result of the conflict match"""
-        print("%d/%d different strings have conflicts" % (len(self.conflictmap), len(self.textmap)))
+        print(
+            "%d/%d different strings have conflicts"
+            % (len(self.conflictmap), len(self.textmap))
+        )
         reducedmap = {}
 
         def str_len(x):
             return len(x)
 
-        for source, translations in six.iteritems(self.conflictmap):
+        for source, translations in self.conflictmap.items():
             words = source.split()
             words.sort(key=str_len)
             source = words[-1]
@@ -164,9 +183,9 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
         for word in reducedmap:
             if word + "s" in reducedmap:
                 plurals[word] = word + "s"
-        for word, pluralword in six.iteritems(plurals):
+        for word, pluralword in plurals.items():
             reducedmap[word].extend(reducedmap.pop(pluralword))
-        for source, translations in six.iteritems(reducedmap):
+        for source, translations in reducedmap.items():
             flatsource = self.flatten(source, "-")
             fulloutputpath = os.path.join(options.output, flatsource + os.extsep + "po")
             conflictfile = po.pofile()
@@ -181,18 +200,33 @@ def main():
     formats = {"po": ("po", None), None: ("po", None)}
     parser = ConflictOptionParser(formats)
     parser.add_option(
-        "-I", "--ignore-case", dest="ignorecase",
-        action="store_true", default=False, help="ignore case distinctions")
+        "-I",
+        "--ignore-case",
+        dest="ignorecase",
+        action="store_true",
+        default=False,
+        help="ignore case distinctions",
+    )
     parser.add_option(
-        "-v", "--invert", dest="invert",
-        action="store_true", default=False, help="invert the conflicts thus extracting conflicting destination words")
+        "-v",
+        "--invert",
+        dest="invert",
+        action="store_true",
+        default=False,
+        help="invert the conflicts thus extracting conflicting destination words",
+    )
     parser.add_option(
-        "", "--accelerator", dest="accelchars", default="",
-        metavar="ACCELERATORS", help="ignores the given accelerator characters when matching")
+        "",
+        "--accelerator",
+        dest="accelchars",
+        default="",
+        metavar="ACCELERATORS",
+        help="ignores the given accelerator characters when matching",
+    )
     parser.set_usage()
     parser.description = __doc__
     parser.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
